<?php

/***************************************************************
 *  Copyright notice
 *
 *  (c) 2009-2010 Mads Sandberg Brun <msb@cs.au.dk>
 *  (c) 2009-2010 Peter Sandberg Brun <psb@cs.au.dk>
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

require_once(t3lib_extMgm::extPath('pure') . 'class.tx_pure_rest.php');
require_once(PATH_typo3 . 'sysext/lang/lang.php');
require_once(t3lib_extMgm::extPath('pure') . 'class.tx_pure_cache.php');

class tx_pure_pagetitle {

    var $cObj;
    var $cacheTime = 86400; //Cache one day.

    function changetitle($content, $conf) {
        $title = $content;
        $pi_vars = t3lib_div::GParrayMerged('tx_pure_pi'); //Get the parameters for the pure plugin
        //var_dump($GLOBALS);
        $sitename = $GLOBALS['TYPO3_CONF_VARS']['SYS']['sitename'];
        //var_dump($content);
        //var_dump($conf);
        //var_dump($GLOBALS['LANG']);
        //TODO: Bad hack. Find langKey from anywhere else....
        $langKey = 'en';
        $langVar = t3lib_div::GPvar('L');
        if (isset($langVar)) {
            if ($langVar === "0") {
                $langKey = 'dk';
            }
        }

        //Get the current language code
        $file = 'EXT:pure/locallang.xml';
        $LANG = t3lib_div::makeInstance('language');
        $LANG->init($langKey);
        $LANG->includeLLFile($file);

        if (isset($pi_vars['personId'])) {
            $name = $this->getPersonName($pi_vars['personId']);
            if ($name) {
                $title = $name; //iconv('UTF-8', $GLOBALS['LANG']->charSet, $name);
            }

        }
        else if (isset($pi_vars['keywordId'])) {
            //$title = $LANG->getLL('page_title_keyword') . $this->getKeywordName($pi_vars['keywordId'], $langKey === 'dk');
            $keywordName = $LANG->getLL('page_title_keyword') . $this->getKeywordName($pi_vars['keywordId'], $langKey === 'dk');
            if ($keywordName) {
                $title = $keywordName;
            } else {
                $title = $LANG->getLL('page_title_keyword');
            }
        }
        else if (isset($pi_vars['pubId'])) {
            $title = $LANG->getLL('page_title_publication');
        } else if (isset($pi_vars['actId'])) {
            $title = $LANG->getLL('page_title_activity');
        } else if (isset($pi_vars['sword']) && isset($pi_vars['search_type'])) {
            $type = $pi_vars['search_type'];
            if ($type == 'publications') {
                $title = $LANG->getLL('page_title_search_publication');
            } else if ($type == 'activities') {
                $title = $LANG->getLL('page_title_search_activity');
            } else if ($type == 'persons') {
                $title = $LANG->getLL('page_title_search_person');
            }
        } else {
            $title = $content; //Set the title it already is.
        }
        return $title;
    }

    private function getPureUrl() {
        //TODO: get url from TS settings.
        return 'http://pureserver.daimi.au.dk/ws/';
    }

    function getKeywordName($keywordId, $primary) {
        $url = $this->getPureUrl();
        $cacheKey = array($url . '?keyword=' . $keywordId);

        $cachedName = tx_pure_cache::getCachedData($cacheKey, $this->cacheTime);
        if ($cachedName) {
            if ($primary) {
                return $cachedName['title_pri'];
            } else {
                return $cachedName['title_sec'];
            }
        }

        $rest = new tx_pure_rest($url);
        $params = array('uris.uri' => $keywordId);
        $keywordXml = $rest->callFunction('classifications', $params);
        if ($keywordXml) {
            $xp = new DOMXPath($keywordXml);

            $title_sec = $xp->evaluate('string(//core:content[1]/core:term[locale = \'en_GB\'])');
            $title_pri = $xp->evaluate('string(//core:content[1]/core:term[locale = \'da_DK\'])');
            if ($title_sec || $title_pri) {
                $resultArray = array('title_sec' => $title_sec, 'title_pri' => $title_pri);
                tx_pure_cache::insertCachedData($cacheKey, $resultArray, $this->cacheTime);
                if ($primary) {
                    return $resultArray['title_pri'];
                } else {
                    return $resultArray['title_sec'];
                }
            }
        }
        return '';
    }

    function getPersonName($personId) {
        $url = $this->getPureUrl();
        $params = array('uuids.uuid' => $personId,
            'rendering' => 'xml_short',
            'window.size' => 1,
            'state' => 'active'); //Display only for active persons

        $key = array($url . 'getPersonsName?' . 'personnelIds=' . $personId);

        $cachedName = tx_pure_cache::getCachedData($key, $this->cacheTime);
        if ($cachedName) {
            return $cachedName;
        }
        //var_dump($params);
        $rest = new tx_pure_rest($url);
        $xml = $rest->getPersons($params);

        if ($xml) {
            $xp = new DOMXPath($xml);
            $items = $xp->query('//core:result/core:content[1]');
            if ($items->length) {
                $item = $items->item(0);
                $name = $xp->evaluate('string(person:name/core:firstName)', $item) . ' ' . $xp->evaluate('string(person:name/core:lastName)', $item);
                tx_pure_cache::insertCachedData($name, $key, $this->cacheTime);
                return $name;
            }
        }
        return '';
    }

}

if (defined('TYPO3_MODE') && $TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['ext/pure/class.tx_pure_pagetitle.php']) {
    include_once($TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['ext/pure/class.tx_pure_pagetitle.php']);
}
?>