<?php
/***************************************************************
 *  Copyright notice
 *
 *  (c) 2009-2010 Mads Sandberg Brun <msb@cs.au.dk>
 *  (c) 2009-2010 Peter Sandberg Brun <psb@cs.au.dk>
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/
/**
 * [CLASS/FUNCTION INDEX of SCRIPT]
 *
 *
 *
 *
 */
/**
 * Class that communicate with the REST interface of the PURE server.
 *
 * @author	Mads Sandberg Brun <msb@cs.au.dk>
 * @author	Peter Sandberg Brun <psb@cs.au.dk>
 * @package	TYPO3
 * @subpackage	tx_pure
 */
class tx_pure_rest
{
	
	var $pureUrl;
	var $pi;
	var $extKey = 'pure';
	
	function __construct($pureServerUrl, $pi = NULL)
	{
		$this->pureUrl = $pureServerUrl;
		$this->pi = $pi;
	}
	
	public function getPersons(array $params)
	{
		$function = 'persons';
		$xmlDoc = $this->callFunction($function, $params);
		return $xmlDoc;
	}
	
	public function getPublications(array $params)
	{
		$function = 'publications';
		$xmlDoc = $this->callFunction($function, $params);
		return $xmlDoc;
	}
	
	public function getActivities(array $params)
	{
		$function = 'activities';
		$xmlDoc = $this->callFunction($function, $params);
		return $xmlDoc;
	}
	
	public function getOrganisations(array $params)
	{
		$function = 'organisations';//'getOrganisations';
		$xmlDoc = $this->callFunction($function, $params);
		return $xmlDoc;
	}
	
	public function getPersonKeywordCompilations(array $params)
	{
		$function = 'getPersonKeywordCompilations';
		$xmlDoc = $this->callFunction($function, $params);
		return $xmlDoc;
	}

    public function getClassificationschemeHierarchy($baseUri)
	{
		$function = 'classificationschemehierarchy';
		$xmlDoc = $this->callFunction($function, array(
				'baseUri' => $baseUri
		));
		return $xmlDoc;
	}


    /**
     * Checks if the PURE server is up and running.
     * Checks if XML is returned.
     * @return boolean True if the PURE server is alive.
     */
    public function isAlive()
    {
        $function = 'servermeta';
        if ($this->callFunction($function))
        {
            return TRUE;
        }
        return FALSE;
    }
	
	
	public function callFunction($function, array $params = array())
	{
        $params['requestOptions.serializeRequest'] =  'true';
		$requestUrl = $this->getURI($this->pureUrl, $function, $params);
		//var_dump($requestUrl);
		//t3lib_div::devlog(microtime(). '(Get URL)'. $function, $this->extKey, 0,  array($requestUrl));
		$xmlDoc = @$this->getXMLDoc($requestUrl);
		//var_dump($requestUrl);
		if($xmlDoc == NULL)
		{
			return NULL;
		}
		
		//Call hooks:
		//t3lib_div::devlog(microtime(). '(Before Proces)'. $function, $this->extKey, 0,  $params);
		$this->callHooks($function, $xmlDoc, $params);
		//t3lib_div::devlog(microtime(). '(After Proces) '.$function, $this->extKey, 0,  $params);
		return $xmlDoc;
	}
	
	private function callHooks($function, $xmlDoc, array $hookParams = array())
	{
		if($this->pi != NULL)
		{
			global $TYPO3_CONF_VARS;
			$hookObjectsArr = array();
			if (is_array ($TYPO3_CONF_VARS['EXTCONF']['pure'][$function])) {
				foreach ($TYPO3_CONF_VARS['EXTCONF']['pure'][$function] as $classRef) {
					$hookObjectsArr[] = t3lib_div::getUserObj($classRef);
				}
			}
			$this->hookObjectsArr = $hookObjectsArr;
			
			foreach($this->hookObjectsArr as $hookObj)	{
				if (method_exists($hookObj, 'process')) {
					$hookObj->process($xmlDoc, $this->pi, $hookParams);
				}
			}
		}
	}

	/**
	 * [Describe function...]
	 *
	 * @param	[type]		$method: ...
	 * @param	[type]		$parray: ...
	 * @param	[type]		$parray: ...
	 * @return	[type]		...
	 */
	private function getURI($url, $method, array $parray)
	{
		//var_dump($parray);
		//http://pure3a.au.dk:8080/ws/axis2/services/PureWebService/
		//if ($GLOBALS['TYPO3_CONF_VARS']['EXTCONF']['pure'])
		//	$baseUrl = $GLOBALS['TYPO3_CONF_VARS']['EXTCONF']['pure']['baseUrl'];
		$rs= $url . 'rest/' . $method;
		$qs="";
		foreach($parray as $par=>$value){
			//$qs=$qs."$par=".rawurlencode($value)."&";
			$qs=$qs."$par=".$value ."&";
		}
		$uri="$rs?$qs";
		return $uri;
	}

	/**
	 * [Describe function...]
	 *
	 * @param	[type]		$uri: ...
	 * @return	[type]		...
	 */
	private function getXMLDoc($uri)
	{
		$xmlDoc = new DomDocument;
        $succes = $xmlDoc->loadXML(t3lib_div::getURL($uri));
		if(!$succes)
		{
			t3lib_div::devlog(microtime(). 'XML is not loaded. Is it valid xml? Check url.', 'pure', 2,  array('url' => $uri));
			return null;
		}
		return $xmlDoc;
	}

	
	
}
if (defined('TYPO3_MODE') && $TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['ext/pure/class.tx_pure_rest.php']) {
	include_once($TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['ext/pure/class.tx_pure_rest.php']);
}

?>