<?php
/***************************************************************
 *  Copyright notice
 *
 *  (c) 2010 Mads Sandberg Brun <msb@cs.au.dk>
 *  (c) 2010 Peter Sandberg Brun <psb@cs.au.dk>
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/
/**
 * [CLASS/FUNCTION INDEX of SCRIPT]
 *
 *
 *
 *
 */
/**
 * The format of tag:
 *  <pure template="name" type="[person/acitivity/publication]" function="[list/single]"  >extraParam1=value1,...,extraParamN=valueN</pure>
 *
 * Example:
 * <pure template="TEMPLATE_SINGLE_PERSON_BASIC" type="person" function="single">personId=psb@cs.au.dk</pure>
 *
 * TS Setup to use this feature (tt_content) (Which are used?):
 *
 *  RTE.default.proc.allowTags := addToList(pure)
    RTE.default.proc.entryHTMLparser_db.allowTags  := addToList(pure)
    RTE.default.FE.proc.allowTags  := addToList(pure)
    RTE.default.FE.proc.entryHTMLparser_db.allowTags  := addToList(pure)

    RTE.default.proc.denyTags := removeFromList(pure)
    #
    # HTMLparser_rte settings
    #
    RTE.default.proc.HTMLparser_rte = 1
    #
    # don't mask special html characters like < or >
    #
    RTE.default.proc.HTMLparser_rte.htmlSpecialChars = 0
    #
    # protect specific, user defined tags
    #
    RTE.default.proc.HTMLparser_rte.tags.pure.protect = 1
    #

    #
    # entryHTMLparser_db settings
    #
    # special html characters like < or > will be stored unmasked (get masked by re-display in RTE)
    #
    RTE.default.proc.entryHTMLparser_db.htmlSpecialChars = -1
    #
    # protect specific tag
    #
    RTE.default.proc.entryHTMLparser_db.tags.pure.protect = 1
    #
    # protect non matching tags
    #
    RTE.default.proc.entryHTMLparser_db.keepNonMatchedTags = protect
    #

    #
    # exitHTMLparser_db settings
    #
    RTE.default.proc.exitHTMLparser_db = 1
    #
    # protected non matched tags during fetching from database
    #
    RTE.default.proc.exitHTMLparser_db.keepNonMatchedTags = 1
    #
    # don't mask html characters like < or >
    #
    RTE.default.proc.exitHTMLparser_db.htmlSpecialChars = 0

    lib.parseFunc.allowTags := addToList(pure)
    lib.parseFunc.tags.pure= < plugin.tx_aupuretag_pi1
    lib.parseFunc.nonTypoTagStdWrap.HTMLparser.tags.pure= < plugin.tx_aupuretag_pi1

    lib.parseFunc_RTE.allowTags := addToList(pure)
    lib.parseFunc_RTE.tags.pure= < plugin.tx_aupuretag_pi1
    lib.parseFunc_RTE.nonTypoTagStdWrap.HTMLparser.tags.pure= < plugin.tx_aupuretag_pi1
 *
 *
 * @return string
 */

require_once(t3lib_extMgm::extPath('pure').'pi/class.tx_pure_pi_publications.php');
require_once(t3lib_extMgm::extPath('pure').'pi/class.tx_pure_pi_persons.php');
require_once(t3lib_extMgm::extPath('pure').'pi/class.tx_pure_pi_activities.php');
/**
 * Class to parse and generate PURE tags.
 *
 * @author	Mads Sandberg Brun <msb@cs.au.dk>
 * @author	Peter Sandberg Brun <psb@cs.au.dk>
 * @package	TYPO3
 * @subpackage	tx_pure
 */
class tx_pure_tag
{
    private static $tagName = 'pure';
    private static $templateAttributName = 'template';
    private static $typeAttributName = 'type';
    private static $functionAttributName = 'function';

    /**
     *
     * @param string $templateName The name of the template to use.
     * @param string $type The type of output. One of person, activity, publiction.
     * @param string $function The function to use. single or list
     * @param array $params The parameteres to the $type and $function
     */
	public function generate($template, $type, $function, array $params)
	{
		$output = '<' . self::$tagName;
        $output .= ' '.self::$templateAttributName.'="'. $template .'"';
        $output .= ' '.self::$typeAttributName.'="'. $type .'"';
        $output .= ' '.self::$functionAttributName.'="'. $function .'"';

        $output .= '>';
        
        $paramsFormated = array();
        foreach($params as $key => $value)
        {
            $paramsFormated[] = $key . '='. $value;
        }

        $output .= implode(',', $paramsFormated);
        $output .= '</'.self::$tagName.'>';
        
        return $output;
	}
	
	public function parse(tx_pure_pi $pi)
	{
		$tagParameters = $pi->cObj->parameters;
        $tagContent = $pi->cObj->getCurrentVal();

        $templateName = $tagParameters[self::$templateAttributName];
        $type = $tagParameters[self::$typeAttributName];
        $function = $tagParameters[self::$functionAttributName];

        if (!$templateName)
        {
            return '';
        }

        /*//Build displayConfig
            $displayConfig = $tagParameters;
            unset($displayConfig['template']);
            unset($displayConfig['type']);
            unset($displayConfig['function']);
         * var_dump($displayConfig);
        */

        $displayConfig = array();
        $nameValuePairs = explode(',', $tagContent);
        if (is_array($nameValuePairs))
        {
            foreach($nameValuePairs as $nameValue)
            {
                if (strpos($nameValue,'=') !== FALSE)
                {
                    list($key, $value) = explode('=', $nameValue);
                    $displayConfig[$key] = $value;
                }
            }
        }

        $type_pi = NULL;
        switch ($type) {
            case 'person':
                $type_pi = new tx_pure_pi_persons($pi);
                break;
            case 'acitivity':
                $type_pi = new tx_pure_pi_activities($pi);
                break;
            case 'publication':
                $type_pi = new tx_pure_pi_publications($pi);
                break;
            default:
                return '';
        }
        switch ($function) {
            case 'single':
                return $type_pi->displaySingle($displayConfig, $templateName);
                break;
            case 'list':
                return $type_pi->displayList($displayConfig, $templateName);
            default:
                return '';
        }
        return '';
	}
	
}
if (defined('TYPO3_MODE') && $TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['ext/pure/class.tx_pure_tag.php']) {
	include_once($TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['ext/pure/class.tx_pure_tag.php']);
}

?>