<?php
/***************************************************************
 *  Copyright notice
 *
 *  (c) 2009-2010 Mads Sandberg Brun <msb@cs.au.dk>
 *  (c) 2009-2010 Peter Sandberg Brun <psb@cs.au.dk>
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

require_once(t3lib_extMgm::extPath('pure').'hooks/class.tx_pure_processing.php');
/**
 * [CLASS/FUNCTION INDEX of SCRIPT]
 *
 *
 *
 *   39: class tx_pure_processing_getKeywords implements tx_pure_processing
 *   49:     public function process($xml, tx_pure_pi $pi)
 *
 * TOTAL FUNCTIONS: 1
 * (This index is automatically created/updated by the extension "extdeveval")
 *
 */
class tx_pure_processing_getKeywords implements tx_pure_processing {

	/**
	 * Used to insert localized links before doing XSLT transformation.
	 *
	 * @param	object		$xml: The XML document from the PURE webservice.
	 * @param	object		$pi: The tx_pure_pi object.
	 * @return	void
	 */
	public function process(DOMDocument $xml, tx_pure_pi $pi, array $hookParams = array())
	{
		$xp = new DOMXPath($xml);

		//Add url to every keyword.
		$keywords = $xp->query("//core:node");
		foreach($keywords as $keyword)
        {
			$keyId = $xp->evaluate('string(core:classification/core:uri)', $keyword);
			if($keyId)
			{
				$link = $keyword->appendChild(new DOMElement('keywordUrl'));
				$url = $pi->pi_linkTP_keepPIvars_url(array('keywordId' => $keyId), $this->allowCaching, 1,  $this->conf['singlePid']);
	   			$text = $link->appendChild(new DOMText($url));
			}
		}
        if ($hookParams['personEmployeeIds.value'])
        {
            $this->injectUserDefinedKeywords($xml, $pi, $hookParams['personEmployeeIds.value']);
        }
	}

    /**
     * Injects the (<core:userDefinedKeyword id="30905433" locale="da_DK" >) tags from
     * the persons function into the keywordsfromperson result node with the same URI.
     * @param DOMDocument $keywordXml
     * @param tx_pure_pi $pi
     * @param <type> $personId
     */
    private function injectUserDefinedKeywords(DOMDocument $keywordXml, tx_pure_pi $pi, $personId)
    {
        $rest =  new tx_pure_rest($pi->pureUrl, null);
        $personParams = array(
            'uuids.uuid' => $personId,
            'rendering' => 'xml_long',
            'window.size' => -1
        );

        $personXml = $rest->getPersons($personParams);
        if ($personXml)
        {
            $personXP = new DOMXPath($personXml);
            $keywordXP = new DOMXPath($keywordXml);

            $keywordContainers = $personXP->query('//person:KeywordContainers/core:keywordContainer[core:userDefinedKeyword]');
            foreach($keywordContainers as $keywordContainer)
            {
                //Get the uri for which the userDefinedKeyword is defined
                $uri = $personXP->evaluate('string(core:target/core:uri)', $keywordContainer);

                //Get the userDefinedKeywords
                $userDefinedKeywords = $personXP->query('core:userDefinedKeyword', $keywordContainer);

                //Find the destination node in the keywordsfromperson result ($xml)
                $destNodes = $keywordXP->query("//core:node[core:classification/core:uri='".$uri."']");

                if ($destNodes->length)
                {
                    $destNode = $destNodes->item(0);

                    //Inject the keywords
                    foreach($userDefinedKeywords as $userDefinedKeyword)
                    {
                        $destNode->appendChild($keywordXml->importNode($userDefinedKeyword, TRUE));
                    }
                }
            }
        }
    }
}


if (defined('TYPO3_MODE') && $TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['ext/pure/hooks/class.tx_pure_processing_getKeywords.php']) {
	include_once($TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['ext/pure/hooks/class.tx_pure_processing_getKeywords.php']);
}

?>