<?php
/***************************************************************
 *  Copyright notice
 *
 *  (c) 2009-2010 Mads Sandberg Brun <msb@cs.au.dk>
 *  (c) 2009-2010 Peter Sandberg Brun <psb@cs.au.dk>
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

require_once(t3lib_extMgm::extPath('pure').'hooks/class.tx_pure_processing.php');
/**
 * [CLASS/FUNCTION INDEX of SCRIPT]
 *
 *
 *
 *   41: class tx_pure_processing_getPersons implements tx_pure_processing
 *   51:     public function process($xml, tx_pure_pi $pi)
 *  105:     private function removeWrongTypes($personXML, tx_pure_pi $pi)
 *  144:     private function isPhdStudent($jobTitle_pri, $jobTitle_sec)
 *
 * TOTAL FUNCTIONS: 3
 * (This index is automatically created/updated by the extension "extdeveval")
 *
 */
class tx_pure_processing_getPersons implements tx_pure_processing {


	/**
	 * Used to insert localized links before doing XSLT transformation.
	 *
	 * @param	object		$xml: The XML document from the PURE webservice.
	 * @param	object		$pi: The tx_pure_pi object.
	 * @return	void
	 */
	public function process(DOMDocument $xml, tx_pure_pi $pi, array $hookParams = array())
	{
		
		//$this->removeWrongTypes($xml, $pi); //Use $hookParams

		$xp = new DOMXPath($xml);

		$domNodeList = $xp->query('//core:result/core:content');
		foreach($domNodeList as $domNode){
			$typo3 = $domNode->appendChild(new DOMElement("typo3"));
		    $node = $typo3->appendChild(new DOMElement("links"));

		    $personId = $xp->evaluate('string(@uuid)', $domNode);
		    //var_dump($personId);
		   	//Add publink, if they exist
		   	if ($personId)
		   	{
		   		$link = $node->appendChild(new DOMElement('publicationUrl'));
		   		$url = $pi->pi_linkTP_keepPIvars_url(array('showType' => 'pub' , 'personId' => $personId), $pi->allowCaching, 1,  $pi->conf['singlePid']);
                $text = $link->appendChild(new DOMText($url));

				$link = $node->appendChild(new DOMElement('activitiesUrl'));
		   		$url = $pi->pi_linkTP_keepPIvars_url(array('showType' => 'act', 'personId' => $personId), $pi->allowCaching, 1,  $pi->conf['singlePid']);
		   		$text = $link->appendChild(new DOMText($url));

				$link = $node->appendChild(new DOMElement('keywordUrl'));
			   	$url = $pi->pi_linkTP_keepPIvars_url(array('showType' => 'keyword', 'personId' => $personId), $pi->allowCaching, 1,  $pi->conf['singlePid']);
			   	$text = $link->appendChild(new DOMText($url));

			   	$link = $node->appendChild(new DOMElement('personUrl'));
			   	$url = $pi->pi_linkTP_keepPIvars_url(array('personId' => $personId, 'showType' => null), $pi->allowCaching, 1,  $pi->conf['singlePid']);
			   	$text = $link->appendChild(new DOMText($url));


                $domOrganisationList = $xp->query('person:organisationAssociations/person:organisationAssociation', $domNode);
                foreach($domOrganisationList as $domOrganisationNode){
                    $email = $xp->evaluate('string(person:email)', $domOrganisationNode);
                    $emailLink = $domOrganisationNode->appendChild(new DOMElement('emailLink'));
                    $url = $pi->pi_linkToPage($email, $email);
                    $emailLink->appendChild(new DOMText(utf8_encode($url)));
                }

			   	$link = $node->appendChild(new DOMElement('cvUrl'));
			   	$url = $pi->pi_linkTP_keepPIvars_url(array('showType' => 'cv', 'personId' => $personId), $pi->allowCaching, 1,  $pi->conf['singlePid']);
			   	$text = $link->appendChild(new DOMText($url));

		   	}
		}
	}

	/**
	 * Temp. hack. Should be removed, when PURE will use ph.d. in type.!
	 *
	 * @param	[type]		$personXML, tx_pure_pi $pi: ...
	 * @return	[type]		...
	 */
	private function removeWrongTypes(DOMDocument $personXML, tx_pure_pi $pi)
	{
		$xp = new DOMXPath($personXML);
		if (!$pi->personType || $pi->personType == 'all' || $pi->personType == 'TAP')
			return;
		$removeStudents = $pi->personType == 'VIP';

		$personsToRemove = array();

		$domNodeList = $xp->query('//core:result/core:content');
		foreach($domNodeList as $domNode)
		{
			$jobTitle_pri = $xp->evaluate("string(person:organisationAssociations/person:organisationAssociation[person:jobTitle][1]/person:jobTitle/core:term/core:localizedString[@locale='da_DK'])", $domNode);
			$jobTitle_sec = $xp->evaluate("string(person:organisationAssociations/person:organisationAssociation[person:jobTitle][1]/person:jobTitle/core:term/core:localizedString[@locale='en_GB'])", $domNode);
			
			$isPhdStudent = $this->isPhdStudent($jobTitle_pri, $jobTitle_sec);
			$isStudent = $this->isStudent($jobTitle_pri, $jobTitle_sec);
			
			if($removeStudents && ($isStudent || $isPhdStudent))
			{
				//Remove student or phd student
				$personsToRemove[] = $domNode;
			}
			else if($pi->personType == 'PHD' && !$isPhdStudent)
			{
				//Remove non phd. student.
				$personsToRemove[] = $domNode;
			}
			else if ($pi->personType == 'STUD' && !$isStudent)
			{
				//Remove non student.
				$personsToRemove[] = $domNode;
			}
		}

		foreach( $personsToRemove as $person ){
		  	$person->parentNode->removeChild($person);
		}
	}

	/**
	 * [Describe function...]
	 *
	 * @param	[type]		$jobTitle_pri: ...
	 * @param	[type]		$jobTitle_sec: ...
	 * @return	[type]		...
	 */
	private function isPhdStudent($jobTitle_pri, $jobTitle_sec)
	{
		$phdStudent = '/.*(ph.?d).*(student|studerende|stipendiat|fellow|scholar).*/i';
		return preg_match($phdStudent, strtolower($jobTitle_pri)) > 0
				|| preg_match($phdStudent, strtolower($jobTitle_sec)) > 0;
	}
	
/**
	 * [Describe function...]
	 *
	 * @param	[type]		$jobTitle_pri: ...
	 * @param	[type]		$jobTitle_sec: ...
	 * @return	[type]		...
	 */
	private function isStudent($jobTitle_pri, $jobTitle_sec)
	{
		$student = '/^(student|studerende)/i';
		return preg_match($student, strtolower($jobTitle_pri)) > 0
				|| preg_match($student, strtolower($jobTitle_sec)) > 0;
	}
}


if (defined('TYPO3_MODE') && $TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['ext/pure/hooks/class.tx_pure_processing_getPersons.php']) {
	include_once($TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['ext/pure/hooks/class.tx_pure_processing_getPersons.php']);
}

?>