<?php
/***************************************************************
 *  Copyright notice
 *
 *  (c) 2009-2010 Mads Sandberg Brun <msb@cs.au.dk>
 *  (c) 2009-2010 Peter Sandberg Brun <psb@cs.au.dk>
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

require_once(t3lib_extMgm::extPath('pure').'hooks/class.tx_pure_processing.php');
/**
 * [CLASS/FUNCTION INDEX of SCRIPT]
 *
 *
 *
 *   39: class tx_pure_processing_getPublications implements tx_pure_processing
 *   49:     public function process($xml, tx_pure_pi $pi)
 *
 * TOTAL FUNCTIONS: 1
 * (This index is automatically created/updated by the extension "extdeveval")
 *
 */
class tx_pure_processing_getPublications implements tx_pure_processing {


	/**
	 * Used to insert localized links before doing XSLT transformation.
	 *
	 * @param	object		$xml: The XML document from the PURE webservice.
	 * @param	object		$pi: The tx_pure_pi object.
	 * @return	void
	 */
	public function process(DOMDocument $xml, tx_pure_pi $pi, array $hookParams = array())
	{
		$xp = new DOMXPath($xml);
		$domNodeList = $xp->query('//core:result/core:content');
		foreach($domNodeList as $domNode){
			$typo3 = $domNode->appendChild(new DOMElement("typo3"));
		    $node = $typo3->appendChild(new DOMElement("links"));

		    $pubId = $xp->evaluate('string(@uuid)', $domNode);
		   	//Add publink, if they exist
		   	if ($pubId)
		   	{
			    $link = $node->appendChild(new DOMElement('publicationUrl'));
			   	$url = $pi->pi_linkTP_keepPIvars_url(array('pubId' => $pubId, 'personId' => $pi->piVars['personId']), $pi->allowCaching, 1,  $pi->conf['singlePid']);
			   	$text = $link->appendChild(new DOMText($url));

			   	$link = $node->appendChild(new DOMElement('publicationAbsoluteUrl'));
                $url = $pi->pi_linkTP_keepPIvars_url(array('pubId' => $pubId, 'personId' => $pi->piVars['personId']), $pi->allowCaching, 1,  $pi->conf['singlePid']);
                if (strpos($url, 'http://') !== 0) //Only handle relative urls.
                    $url = t3lib_div::getIndpEnv('TYPO3_SITE_URL') . $url;
			   	$text = $link->appendChild(new DOMText($url));
		   	}
            
		   	$link = $node->appendChild(new DOMElement('TYPO3_SITE_URL'));
		   	$url = t3lib_div::getIndpEnv('TYPO3_SITE_URL');
		   	$text = $link->appendChild(new DOMText($url));

		   	$authorsEditorsList = $xp->query('(publication:persons/person:personAssociation)', $domNode);
			foreach($authorsEditorsList as $author)
			{
				$personId = $xp->evaluate('string(person:person/@uuid)', $author);
				if($personId)
				{
					$link = $author->appendChild(new DOMElement('link'));
                    $personUrl = $link->appendChild(new DOMElement('personUrl'));
			   		$url = $pi->pi_linkTP_keepPIvars_url(array('personId' => $personId), $pi->allowCaching, 1,  $pi->conf['singlePid']);
			   		$text = $personUrl->appendChild(new DOMText($url));
				}
			}

			
		//TODO: PURE 4. No category any more. Types only
			//The category Information and Education should be grouped to the same. (says NJR)
			/*
			 
			 if ($xp->evaluate('string(publicationCategory)', $domNode) == 'Education')
			{
				$catElements = $xp->evaluate('publicationCategory', $domNode);
				if($catElements->length > 0)
				{
					$catElement = $catElements->item(0);
					$newCatElement = $catElement->cloneNode(false);
					$newCatElement->appendChild(new DOMText('Information'));
					$catElement->parentNode->replaceChild($newCatElement, $catElement);
				}
			}
			*/

            //Add grouping values here:
            //publicationYear  => publication:publicationDate/core:year
            //publicationType => publication:typeClassification/core:term/core:localizedString[@locale= 'en_GB' /'da_DK']
            //submittedYear => publication:submissionYear

            $publicationYear = $domNode->appendChild(new DOMElement("publicationYear"));
            $text = $publicationYear->appendChild(new DOMText($xp->evaluate('string(publication:publicationDate/core:year)', $domNode)));

            $submittedYear = $domNode->appendChild(new DOMElement("submittedYear"));
            $text = $submittedYear->appendChild(new DOMText($xp->evaluate('string(publication:submissionYear)', $domNode)));

            $publicationType = $domNode->appendChild(new DOMElement("publicationType"));
            $text = $publicationType->appendChild(new DOMText($xp->evaluate("string(publication:typeClassification/core:term/core:localizedString[@locale='en_GB'])", $domNode)));
		}

		$typo3 = $xml->appendChild(new DOMElement("typo3"));
	    $node = $typo3->appendChild(new DOMElement("links"));
		//Add sorting links:

	    $link = $node->appendChild(new DOMElement('sortDateUrl'));
   		$url = $pi->pi_linkTP_keepPIvars_url(array('pubsort' => 'publicationYear', 'showType' => $pi->piVars['showType'], 'personId' => $pi->piVars['personId'], 'showAll' => $pi->piVars['showAll'], 'sword' => $pi->piVars['sword']), $pi->allowCaching, 0);
   		$text = $link->appendChild(new DOMText($url));

   		$link = $node->appendChild(new DOMElement('sortTitleUrl'));
   		$url = $pi->pi_linkTP_keepPIvars_url( array('pubsort' => 'title', 'showType' =>$pi->piVars['showType'], 'personId' => $pi->piVars['personId'], 'showAll' => $pi->piVars['showAll'], 'sword' => $pi->piVars['sword']), $pi->allowCaching, 0);
   		$text = $link->appendChild(new DOMText($url));

   		$link = $node->appendChild(new DOMElement('sortAuthorUrl'));
   		$url = $pi->pi_linkTP_keepPIvars_url( array('pubsort' => 'authorLastName', 'showType' =>$pi->piVars['showType'], 'personId' => $pi->piVars['personId'], 'showAll' => $pi->piVars['showAll'], 'sword' => $pi->piVars['sword']), $pi->allowCaching, 0);
   		$text = $link->appendChild(new DOMText($url));

   		$link = $node->appendChild(new DOMElement('sortPublicationTypeIndexUrl'));
   		$url = $pi->pi_linkTP_keepPIvars_url( array('pubsort' => 'typeClassification', 'showType' =>$pi->piVars['showType'], 'personId' => $pi->piVars['personId'], 'showAll' => $pi->piVars['showAll'], 'sword' => $pi->piVars['sword']), $pi->allowCaching, 0);
   		$text = $link->appendChild(new DOMText($url));

   		$link = $node->appendChild(new DOMElement('sortPublicationTypeIndexFirstAuthorUrl'));
   		$url = $pi->pi_linkTP_keepPIvars_url( array('pubsort' => 'typeClassification,authorLastName', 'showType' =>$pi->piVars['showType'], 'personId' => $pi->piVars['personId'], 'showAll' => $pi->piVars['showAll'], 'sword' => $pi->piVars['sword']), $pi->allowCaching, 0);
   		$text = $link->appendChild(new DOMText($url));

   		$link = $node->appendChild(new DOMElement('sortSubmittedYearUrl'));
   		$url = $pi->pi_linkTP_keepPIvars_url( array('pubsort' => 'submissionYear', 'showType' =>$pi->piVars['showType'], 'personId' => $pi->piVars['personId'], 'showAll' => $pi->piVars['showAll'], 'sword' => $pi->piVars['sword']), $pi->allowCaching, 0);
   		$text = $link->appendChild(new DOMText($url));

   		$link = $node->appendChild(new DOMElement('sortSubmittedYearFirstAuthorUrl'));
   		$url = $pi->pi_linkTP_keepPIvars_url( array('pubsort' => 'submissionYear,authorLastName', 'showType' =>$pi->piVars['showType'], 'personId' => $pi->piVars['personId'], 'showAll' => $pi->piVars['showAll'], 'sword' => $pi->piVars['sword']), $pi->allowCaching, 0);
   		$text = $link->appendChild(new DOMText($url));

   		$link = $node->appendChild(new DOMElement('sortSubmittedYearPublicationTypeIndexFirstAuthorUrl'));
   		$url = $pi->pi_linkTP_keepPIvars_url( array('pubsort' => 'submissionYear,typeClassification,authorLastName', 'showType' =>$pi->piVars['showType'], 'personId' => $pi->piVars['personId'], 'showAll' => $pi->piVars['showAll'], 'sword' => $pi->piVars['sword']), $pi->allowCaching, 0);
   		$text = $link->appendChild(new DOMText($url));

   		//Ascending/Descending links
   		$link = $node->appendChild(new DOMElement('sortAscUrl'));
   		$url = $pi->pi_linkTP_keepPIvars_url( array('pubsort' => $pi->piVars['pubsort'], 'sortdirection' => 'asc',  'showType' =>$pi->piVars['showType'], 'personId' => $pi->piVars['personId'], 'showAll' => $pi->piVars['showAll'], 'sword' => $pi->piVars['sword']), $pi->allowCaching, 0);
   		$text = $link->appendChild(new DOMText($url));

   		$link = $node->appendChild(new DOMElement('sortDescUrl'));
   		$url = $pi->pi_linkTP_keepPIvars_url( array('pubsort' => $pi->piVars['pubsort'], 'sortdirection' => 'desc',  'showType' =>$pi->piVars['showType'], 'personId' => $pi->piVars['personId'], 'showAll' => $pi->piVars['showAll'], 'sword' => $pi->piVars['sword']), $pi->allowCaching, 0);
   		$text = $link->appendChild(new DOMText($url));



		$link = $node->appendChild(new DOMElement('allPublicationsUrl'));
   		$url = $pi->pi_linkTP_keepPIvars_url(array('showType' => $pi->piVars['showType'], 'showAll' => 'true', 'personId' => $pi->piVars['personId'],'pubsort' => $pi->piVars['pubsort']), $pi->allowCaching, 1);
   		$text = $link->appendChild(new DOMText($url));

   		$link = $node->appendChild(new DOMElement('selectedPublicationsUrl'));
   		$url = $pi->pi_linkTP_keepPIvars_url(array('showType' => $pi->piVars['showType'], 'showAll' => 'false', 'personId' => $pi->piVars['personId'],'pubsort' => $pi->piVars['pubsort']), $pi->allowCaching, 1);
   		$text = $link->appendChild(new DOMText($url));

		//RSS Link:
		$link = $node->appendChild(new DOMElement('rssUrl'));
   		$rssUrl = $pi->pi_linkTP_keepPIvars_ajax_id_url( array( 'showType' => 'pubrss', 'personId' => $pi->piVars['personId']) , $pi->allowCaching, 1);
   		$text = $link->appendChild(new DOMText($rssUrl));

   		//Absolute RSS Link:
		$link = $node->appendChild(new DOMElement('rssAbsoluteUrl'));
   		$rssUrl = t3lib_div::getIndpEnv('TYPO3_SITE_URL').$pi->pi_linkTP_keepPIvars_ajax_id_url( array( 'showType' => 'pubrss', 'personId' => $pi->piVars['personId']) , $pi->allowCaching, 1);
   		$text = $link->appendChild(new DOMText($rssUrl));

   		//Link to publications:
   		$link = $node->appendChild(new DOMElement('rssSoruceUrl'));
   		$rssSourceUrl = t3lib_div::getIndpEnv('TYPO3_SITE_URL'). $pi->pi_linkTP_keepPIvars_url(array(), $pi->allowCaching, 1);
   		$text = $link->appendChild(new DOMText($rssSourceUrl));

		//var_dump($rssUrl);
//		$tree['rss_url'] = $rssUrl;
//		$tree['rss_url_abs'] = t3lib_div::getIndpEnv('TYPO3_SITE_URL').$rssUrl;


        

	}
}


if (defined('TYPO3_MODE') && $TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['ext/pure/hooks/class.tx_pure_processing_getPublications.php']) {
	include_once($TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['ext/pure/hooks/class.tx_pure_processing_getPublications.php']);
}

?>