<?php
/***************************************************************
 *  Copyright notice
 *
 *  (c) 2010 Mads Sandberg Brun <msb@cs.au.dk>
 *  (c) 2010 Peter Sandberg Brun <psb@cs.au.dk>
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/
require_once(t3lib_extMgm::extPath('pure').'class.tx_pure_rest.php');
require_once(t3lib_extMgm::extPath('pure').'class.tx_pure_cache.php');
/**
 * AJAX functions for 'pure'
 *
 * @subpackage	pure
 */
class tx_pure_pi_ajax {

	public function getOrganisationsHiearchy(array $params, TYPO3AJAX &$ajaxObj) {

        $pureserver = t3lib_div::_GP('pureserver');
        $params = array(
                'rendering' => 'xml_long',
                'window.size' => -1,
                'window.offset' => 0,
                'active' => 'true',
                );

        $XSLTName = t3lib_div::getFileAbsFileName('EXT:pure/pi/xsl/organisationstree_json.xsl');
        $this->printJson($pureserver, 'organisations', $params, $XSLTName, $ajaxObj);
	}

    public function getPublicationTypesHiearchy(array $params, TYPO3AJAX &$ajaxObj)
    {
        $this->getClassificationschemeHiearchy('/dk/atira/pure/publication/publicationtypes', $params, $ajaxObj);
	}

    public function getActivityTypesHiearchy(array $params, TYPO3AJAX &$ajaxObj)
    {
        $this->getClassificationschemeHiearchy('/dk/atira/pure/activity/activitytypes', $params, $ajaxObj);
	}
    
    public function getOrganisationTypesHiearchy(array $params, TYPO3AJAX &$ajaxObj)
    {
        $this->getClassificationschemeHiearchy('/dk/atira/pure/organisation/organisationtypes', $params, $ajaxObj);
	}

    public function getEmploymentTypesHiearchy(array $params, TYPO3AJAX &$ajaxObj)
    {
        $this->getClassificationschemeHiearchy('/dk/atira/pure/person/employmenttypes', $params, $ajaxObj);
	}

    public function getClassificationschemeHiearchy($baseUri, array $params, TYPO3AJAX &$ajaxObj)
    {
        $pureserver = t3lib_div::_GP('pureserver');
        $params =  array(
				'baseUri' => $baseUri
		);

        $XSLTName = t3lib_div::getFileAbsFileName('EXT:pure/pi/xsl/classificationschemehierarchytree_json.xsl');
        $this->printJson($pureserver, 'classificationschemehierarchy', $params, $XSLTName, $ajaxObj);
    }


    public function getPersonsSearch(array $params, TYPO3AJAX &$ajaxObj)
    {
        $pureserver = t3lib_div::_GP('pureserver');
        $query = t3lib_div::_GP('query');
        $size = t3lib_div::_GP('limit');
        $offset = t3lib_div::_GP('start');
        $params =  array(
				'rendering' => 'xml_long', //To get picture, we need long.
                'state' => 'active',
				'window.offset' => $offset,
				'window.size' => $size,
                'orderBy.property[0]' => 'firstName',
                'orderBy.property[0].descending' => 'false',
                'orderBy.property[1]' => 'lastName',
                'orderBy.property[1].descending' => 'false',
                'searchString' => rawurlencode('name:' .$query . ' OR ' . 'employeeId:' . $query)
		);
        if (t3lib_div::_GP('ids'))
        {
            $params =  array(
				'rendering' => 'xml_short',
                'state' => 'active',
				'window.offset' => 0,
				'window.size' => -1,
                'personEmployeeIds.value' => t3lib_div::_GP('ids')
            );
        }

        $XSLTName = t3lib_div::getFileAbsFileName('EXT:pure/pi/xsl/personsearch_json.xsl');
        $this->printJson($pureserver, 'persons', $params, $XSLTName, $ajaxObj);
    }

    public function getPublicationsSearch(array $params, TYPO3AJAX &$ajaxObj)
    {
        $this->getEntrySearch('publications', 'EXT:pure/pi/xsl/publicationsearch_json.xsl' , $params, $ajaxObj);
    }

    public function getActivitiesSearch(array $params, TYPO3AJAX &$ajaxObj)
    {
        $this->getEntrySearch('activities', 'EXT:pure/pi/xsl/activitysearch_json.xsl' , $params, $ajaxObj);
    }

    public function getEntrySearch($entryFunctionName, $xlst, array $params, TYPO3AJAX &$ajaxObj)
    {
        $pureserver = t3lib_div::_GP('pureserver');
        $query = t3lib_div::_GP('query');
        $size = t3lib_div::_GP('limit');
        $offset = t3lib_div::_GP('start');
        $params =  array(
				'rendering' => 'xml_short',
				'window.offset' => $offset,
				'window.size' => $size,
                'orderBy.property[0]' => 'title',
                'orderBy.property[0].descending' => 'false',
                'searchString' => rawurlencode($query)
		);
        if (t3lib_div::_GP('ids'))
        {
            $params =  array(
				'rendering' => 'xml_short',
				'window.offset' => 0,
				'window.size' => -1,
                'uuids.uuid' => t3lib_div::_GP('ids')
            );
        }
        $XSLTName = t3lib_div::getFileAbsFileName($xlst);
        $this->printJson($pureserver, $entryFunctionName, $params, $XSLTName, $ajaxObj);
    }

    private static function printJson($pureserver, $function, $params, $XSLTName, TYPO3AJAX &$ajaxObj)
    {
        $succes = FALSE;
        if ($pureserver)
        {
            $time = 24 * 60 * 60;
            $cacheKey = array ('json', $pureserver, $function, $params, $XSLTName);
            $json = tx_pure_cache::getCachedData($cacheKey, $time);
            if ($json == NULL)
            {
                $rest = new tx_pure_rest($pureserver); //   /dk/atira/pure/activity/activitytypes
                $reguest = $rest->callFunction($function, $params);
                if ($reguest)
                {
                    $succes = true;
                    $XSL = new DOMDocument();
                    $succes = $XSL->load( $XSLTName, LIBXML_COMPACT);

                    $extraParameters = array();
                    $extraParameters['extRelPath'] = t3lib_extMgm::extRelPath('pure');
                    
                    $json = self::transformXmlWithXsl($reguest, $XSL, $extraParameters);
                    tx_pure_cache::insertCachedData($json, $cacheKey, $time);
                }
            }
            else
                $succes = true;
            if ($succes)
            {
                header('Content-type: application/json; charset=utf-8');
                Header('Cache-Control: public, max-age=' . (int)$time);
                echo $json;
                exit;
            }
        }
        $ajaxObj->addContent('succes', $succes == true ? 'true' : 'false');
        $ajaxObj->setContentFormat('json');
    }

    private static function transformXmlWithXsl($xmlDoc, $xslDoc, $extraParameters = array())
	{
		/*************Make output********************/
		$xslt = new XSLTProcessor();
		$xslt->importStylesheet( $xslDoc );

		//Set grouping parameters
		if (is_array($extraParameters))
		{
			foreach($extraParameters as $k => $param)
			{
				$xslt->setParameter('', $k, $param);
			}
		}
        $xslt->registerPHPFunctions();
		
		$outputXML = $xslt->transformToXML( $xmlDoc);
		return $outputXML;
	}
}

if (defined('TYPO3_MODE') && $TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['ext/pure/pi/ajax.php']) {
	include_once($TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['ext/pure/pi/ajax.php']);
}

?>