<?php
/***************************************************************
 *  Copyright notice
 *
 *  (c) 2009-2010 Mads Sandberg Brun <msb@cs.au.dk>
 *  (c) 2009-2010 Peter Sandberg Brun <psb@cs.au.dk>
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/
/**
 * [CLASS/FUNCTION INDEX of SCRIPT]
 *
 *
 *
 */

require_once(t3lib_extMgm::extPath('pure').'pi/class.tx_pure_pi_base.php');

/**
 * Activity controller for the 'pure' extension.
 *
 * @author	Mads Sandberg Brun <msb@cs.au.dk>
 * @author	Peter Sandberg Brun <psb@cs.au.dk>
 * @package	TYPO3
 * @subpackage	tx_pure
 */
class tx_pure_pi_activities extends tx_pure_pi_base {
    

    /**
	 * Displays a single activity.
	 * The $displayConfig have the following keys:
	 * 		actId: The activity id.
	 *
	 * @param	array		$displayConfig: The configuration array with the following options used.
	 * @param	string		$templateName: The name of the template to use.
	 * @return	string		The output from the template. Etc. HTML.
	 */
	public function displaySingle(array $displayConfig, $templateName)
	{
		if(!$displayConfig['actId'])
			return $this->displayNothing();
		$parray=array(
				'uuids.uuid' => $displayConfig['actId'],
				'rendering' => "xml_long",
				'window.offset' => "0",
				'window.size' => "1",
		);
		$extraParameters = array();
		return $this->transformOutput('activities', $parray, $templateName, $extraParameters);
	}



	/**
	 * Displays multiple activites
	 * The $displayConfig have the following keys:
	 * 		personId: A commaseperated list on persons ids.
	 * 		actIds:
	 * 		orgId:
	 * 		size:
	 * 		groupby:
	 * 		groupby2:
	 * 		actsort:
	 * 		year:
	 * 		ascDesc:
	 * 		selectedByPersons:
	 *
	 * @param	array		$displayConfig: The configuration array with the following options used.
	 * @param	string		$templateName: The name of the template to use.
	 * @param	string		$search: Search input.
	 * @return	string		The output from the template. Etc. HTML.
	 */
	public function displayList(array $displayConfig, $templateName, $search = '')
	{
		$size = intval($displayConfig['size']);
		if (!$size)
			$size = $this->pi->conf['list_size'];
		$this->pi->internal['results_at_a_time'] = $size;

		//Setup pointer
		$page = intval($this->pi->piVars['pointer']);
		if (!$this->pi->config['userclick'] && $_COOKIE["au-activities-pointer"]  && !isset($this->pi->piVars['pointer']))
			$page = intval($_COOKIE["au-activities-pointer"]); //Use the cookie pointer, if page auto loaded.
		else if($this->pi->piVars['actsort'] && $_COOKIE["au-activities-sort"] && $this->pi->piVars['actsort'] != $_COOKIE["au-activities-sort"])
			$page = 0; //Reset pointer to 0, if user chossed new ordering.

		//Set the pointer if, userclick.
		if ($this->pi->config['userclick'])
			setcookie("au-activities-pointer", $page, $page ? $this->pi->cookie_time : 0);

		$this->pi->piVars['pointer'] = $page;

		if($this->pi->piVars['actsort'] || $_COOKIE["au-activities-sort"])
		{
			$displayConfig['actsort'] = $this->pi->piVars['actsort'] ? $this->pi->piVars['actsort'] : $_COOKIE["au-activities-sort"];
			//If no grouping, fix sortings:
			if (!$displayConfig['groupby'] && !$displayConfig['groupby2'])
			{
				if (strtolower($displayConfig['actsort']) ===  'start')
					$displayConfig['ascDesc'] = 'desc';
				else
					$displayConfig['ascDesc'] = 'asc';
			}
			//Save cookie
			setcookie("au-activities-sort", $displayConfig['actsort'], $this->pi->cookie_time);
		}
		else if (empty($displayConfig['actsort']) )
		{
			$displayConfig['actsort'] = 'startDate';
			if (!$displayConfig['groupby'] && !$displayConfig['groupby2'])
				$displayConfig['ascDesc'] = 'desc';
		}



		//Set it descending
		if ($displayConfig['actsort'] == 'startDate' && !$displayConfig['ascDesc'])
			$displayConfig['ascDesc'] = 'desc';

		$displayConfig['personEmployeeIds'] = $this->removeWhiteSpace($displayConfig['personEmployeeIds']);
		if(!$displayConfig['orgId'] && !$displayConfig['personEmployeeIds'] && !$displayConfig['personId'] && !$displayConfig['actIds'] && !$search)
			return $this->displayNothing();

		//Setup start and end date by using year
		$yearStart = $displayConfig['year'];
		$yearEnd = '';
		if ($displayConfig['year'])
		{
			$submitted = explode('-', $displayConfig['year'] );
			if (count($submitted) > 1)
			{
				$yearStart = $submitted[0];
				$yearEnd = $submitted[1];
			}
		}
		if ($yearEnd)
			$yearEnd .= '-01-01T00:00:00.000';
		if ($yearStart)
			$yearStart .= '-01-01T00:00:00.000';


		if (!isset($this->pi->piVars['showAll']))
			$this->pi->piVars['showAll'] = $displayConfig['selectedByPersons'] ? 'false' : 'true';
		$selected = $this->pi->piVars['showAll'] == 'true' ? 'false' : 'true';

        $parray=array(
                'rendering' => "xml_long",
				'window.offset' => $size*$page,
				'window.size' => $size,
            );

        
        //Map Grouping parameter to orderBy parameter for the request. PURE 3 -> 4
        $searchOrder = array('activityType', 'startYear');
        $replacementOrder = array('typeClassification', 'startDate');

        $groupbyOrder = str_replace($searchOrder, $replacementOrder, $displayConfig['groupby']);
        $groupbyOrder2 = str_replace($searchOrder, $replacementOrder, $displayConfig['groupby2']);


        $orderBy = array();
        if ($groupbyOrder)
        {
            $orderBy[$groupbyOrder]  = array( 'name' => $groupbyOrder,
                               'descending' => ($groupbyOrder == 'startDate') ? 'true' : 'false');
        }
        if ($groupbyOrder2)
        {
            $orderBy[$groupbyOrder2]  = array( 'name' => $groupbyOrder2,
                               'descending' => ($groupbyOrder2 == 'startDate') ? 'true' : 'false');
        }

        $orderings = explode(',', $displayConfig['actsort']);
        $first = true;
        if (!empty($orderings))
        {
            foreach($orderings as $order)
            {
                if (!$order)
                    continue;
                $orderBy[$order]  = array( 'name' => $order,
                                            'descending' => 'false');
                if ($first)
                {
                    $orderBy[$order]['descending'] = ($displayConfig['ascDesc'] === 'asc' ? 'false' : 'true');
                    $first = false;
                }

            }
        }

        //Build orderBy.property array
        $index = 0;
        foreach($orderBy as $order)
        {
            $parray['orderBy.property['.$index.']'] = $order['name'];
            $parray['orderBy.property['.$index.'].descending'] = $order['descending'];
            $index++;
        }


		if ($displayConfig['orgId'])//associatedOrganisationUuids.uuid or associatedOrganisationOrganisationIds.value or owningOrganisationUuids
			$parray['owningOrganisationUuids.uuid'] = 	$displayConfig['orgId'];

			//publicationDate.fromDate and publicationDate.toDate. PURE4: A DateTime (2011-01-01T00:00:00.000+01:00). Parsing year to arguments works fine
		if ($yearStart)
			$parray['activityDate.fromDate'] = $yearStart;
		if ($yearEnd)
			$parray['activityDate.toDate'] = $yearEnd;

		if ($search)							//searchString
			$parray['searchString'] = $search;
		else
		{
			if ($displayConfig['personId']) {
				$parray['associatedPersonUuids.uuid'] = $displayConfig['personId'];
            }
            if ($displayConfig['personEmployeeIds']) {
                $parray['associatedPersonEmployeeIds.value'] = $displayConfig['personEmployeeIds'];
            }


			if ($displayConfig['actIds']) //pureInternalIds.id or uuids.uuid
				$parray['uuids.uuid'] = $displayConfig['actIds'];

            if ($displayConfig['activityTypes'])
                $parray['typeClassificationUris.uri'] = $displayConfig['activityTypes'];
		}

        $function = 'activities';
		$altParray = array();

		$extraParameters = array();
		$extraParameters['actsort'] = $displayConfig['actsort'];
		$extraParameters['group1'] = $displayConfig['groupby'];
		$extraParameters['group2'] = $displayConfig['groupby2'];

		return $this->transformOutput($function, $parray, $templateName, $extraParameters, $altParray);

	}



	/**
	 * Displays a search form for activities.
	 *
	 * @param	string		$resultTemplate: The template to use for the results. (Activities template)
	 * @param	string		$formTemplate: The template to use for the searh form.s
	 * @param	string		$orgIds: The organisationids, that can be searched within.
	 * @param	boolean		$onlyResult: If true, only shows the result.
	 * @param	integer		$resultPage: The pageId to redirect to search on submit.
	 * @param	boolean		$onlyForm: If true, only shows the search form.
	 * @return	string		XML.
	 */
	public function displaySearch($resultTemplate, $formTemplate, $orgIds, $onlyResult, $resultPage, $onlyForm)
	{
		$content = '';
		$displayConfig = array();
		$displayConfig['actsort'] = 'title';
		$displayConfig['size'] = 50;
		$displayConfig['startYear'] = htmlspecialchars($this->pi->piVars['startYear']);
		$displayConfig['endYear'] = htmlspecialchars($this->pi->piVars['endYear']);
		$displayConfig['year'] = $displayConfig['startYear']. '-' . $displayConfig['endYear'];
		$displayConfig['activityTypes'] = htmlspecialchars($this->pi->piVars['activityTypes']);
		$displayConfig['organisationIds'] = htmlspecialchars($this->pi->piVars['organisationIds']);
		$displayConfig['orgId'] = $displayConfig['organisationIds'];

		$seachValue = htmlspecialchars($this->pi->piVars['sword']);
		//Get the result with the given template to use the results
		$result = '';
		if ($seachValue && !$onlyForm)
			$result = $this->displayList($displayConfig, $resultTemplate, $seachValue);

		if ($onlyResult)
			$content .= $result;
		else
		{

			//Add extra search specific field to the form
			$extraElement = array();
			$extraElement[] = new DOMElement('organisationIdsToChoose', $orgIds);
			$extraElement[] = new DOMElement('selectedStartYear', intval($displayConfig['startYear']));
			$extraElement[] = new DOMElement('selectedEndYear', intval($displayConfig['endYear']));
			$extraElement[] = new DOMElement('selectedOrganisationIds', $displayConfig['organisationIds']);

			//Organisations
			$orgsDocument = $this->getOrganisationsNamesXML($orgIds);
			if ($orgsDocument->documentElement) {
                $extraElement[] =  $orgsDocument->documentElement;
            }

			$content .= $this->displaySearchFormXSLT($formTemplate, $result, $extraElement, $resultPage );
		}
		return $content;
	}

    protected function getOrganisationPath() {
        return '//core:result/core:content[1]/activity:organisations/organisation:organisation/organisation:organisationId';
    }

}

if (defined('TYPO3_MODE') && $TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['ext/pure/pi/class.tx_pure_pi_activities.php'])	{
	include_once($TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['ext/pure/pi/class.tx_pure_pi_activities.php']);
}


?>
