<?php
/***************************************************************
 *  Copyright notice
 *
 *  (c) 2009-2010 Mads Sandberg Brun <msb@cs.au.dk>
 *  (c) 2009-2010 Peter Sandberg Brun <psb@cs.au.dk>
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/
/**
 * [CLASS/FUNCTION INDEX of SCRIPT]
 *
 *
 *
 */

/**
 * Base controller for the 'pure' extension.
 * Contains common functions.
 *
 * @author	Mads Sandberg Brun <msb@cs.au.dk>
 * @author	Peter Sandberg Brun <psb@cs.au.dk>
 * @package	TYPO3
 * @subpackage	tx_pure
 */
class tx_pure_pi_base {
    //put your code here

    private static $pureNamespace = 'http://typo3.org/extensions/repository/view/pure/current/';

    var $pi;

    function __construct(tx_pure_pi $pi) {
       $this->pi = $pi;
    }



	/**
	 * Gets the the XML-response from the PURE webservice when calling "getOrganisationsNamesFunction" with "ids"=$id.
	 *
	 * @param	string		$id: The ids.
	 * @return	object		The XML document.
	 */
	public function getOrganisationsNamesXML($ids)
	{
		$parray=array(
				'rendering' => 'xml_short',
				'window.size' => '-1',
				'uuids.uuid' => $ids,
                'active' => 'true',
		);
		$rest = new tx_pure_rest($this->pi->pureUrl);

		$uri= $this->pi->pureUrl. 'getOrganisationsNamesFunction?id='. $ids;

		$orgs = $this->pi->getCachedData($uri, 'getOrganisationsNamesFunction');
		if(!isset($orgs))
		{
			$newXml = new DOMDocument();
			$root = $newXml->appendChild(new DOMElement('organisations'));
			$xml = $rest->callFunction('organisations', $parray);

            if ($xml) {
                $xp = new DOMXPath($xml);
                $orgList = $xp->query('//core:result/core:content');
                foreach($orgList as $org){
                    $orgElement = $root->appendChild(new DOMElement('item'));

                    $names = $xp->query('organisation:name', $org);
                    if ($names->length)
                    {
                        $name = $names->item(0);
                        $newName = $newXml->importNode($name, TRUE);
                        $orgElement->appendChild($newName);
                    }
                    $id = $xp->evaluate('string(@uuid)', $org);
                    $orgElement->appendChild(new DOMElement('id', $id));
                }
                $orgs = $newXml->saveXML();
                $this->pi->insertCachedData($uri, 'getOrganisationsNamesFunction', $orgs);
            }
		}

		$newXml = new DOMDocument();
		@$newXml->loadXML($orgs);
		return $newXml;
	}

    /**
	 * Display error message.
	 *
	 * @return	string		The error message.
	 */
	function displayError($errorDescription = '')
	{
        $message = t3lib_div::makeInstance(
            't3lib_FlashMessage',
            $errorDescription,
            $this->pi->pi_getLL('pureErrorTitle'),
            t3lib_FlashMessage::INFO
        );
        return $message->render();
	}

    /**
	 * Display empty string.
	 *
	 * @return	string		The empty string.
	 */
	function displayNothing()
	{
		return '';
	}






    /**
	 * Displays a search form. The following will be passed to the an XSLT template, if for example "$extraElements['resultCount'] = 132"
	 * 			<typo3search>
	 * 				<config>
	 * 					<resultCount>132</resultCount>s
	 * 				</config>
	 * 			</typo3search>
	 *
	 * @param	string		$templateName: The template to use for the searh form.
	 * @param	string		$result: The result XHTML.
	 * @param	array		$extraElements: The extra XML elements to be passed to XSLT.
	 * @param	integer		$resultPage: The pageId to redirect to search on submit.
	 * @return	string		XML.
	 */
	function displaySearchFormXSLT($templateName, $result, array $extraElements, $resultPage)
	{
		$GLOBALS['TSFE']->set_no_cache();

		//Prepare for search template
		$xmlDoc = new DOMDocument();
		$root = $xmlDoc->appendChild(new DOMElement('typo3search'));

		if($result)
		{
			$resultElement = $root->appendChild(new DOMElement('result'));
			$resultElement->appendChild(new DOMText($result));
		}

		$config = $root->appendChild(new DOMElement('config'));

        $extraElements[] = new DOMElement('resultCount', intval($this->pi->getLastResultCount()));
		foreach($extraElements as $element)
		{
			$config->appendChild($xmlDoc->importNode($element, true));
		}

		$config->appendChild(new DOMElement('formUrl',$this->pi->pi_linkTP_keepPIvars_url(array('pointer' => 0, 'cat' => null), 0, 1, $resultPage) ));
		$config->appendChild(new DOMElement('sword',htmlspecialchars($this->pi->piVars['sword'])));

		//Find template file:
		$XSL = new DOMDocument();
		$XSLTName = t3lib_div::getFileAbsFileName('EXT:pure/res/templates/'.$templateName.'.xsl'); //TODO: make configurable.

		$succes = $XSL->load( $XSLTName, LIBXML_COMPACT);
		if($XSL == null || !$succes)
		{
			t3lib_div::devlog(microtime(). 'XSLT was not loaded. Check the file.', $this->pi->extKey, 2,  array('file' => $XSLTName));
			return '';
		}
		$transformedXML = $this->transformXmlWithXsl($xmlDoc, $XSL, $extraParameters);
		if($transformedXML == null)
		{
			t3lib_div::devlog(microtime(). 'Bad XSLT Transformation. Check the file.', $this->pi->extKey, 2,  array('file' => $XSLTName));
			return '';
		}

		$output = $transformedXML->saveXML($transformedXML->documentElement, LIBXML_NOXMLDECL);

		return $output;
	}

    /**
	 * ******************************************************
	 *
	 * 	Template processing functions
	 *
	 * ********************************************************/


	/**
	 * Tranform the XML response given by $function and its parameters with an XSLT file given.
	 *
	 * @param	string		$function: The PURE webservice function to call.
	 * @param	array		$priParams: The primary parameters to be called with the function. If there is no result with this parameters, the $altParams are used.
	 * @param	string		$template: The name of the XSLT file to use.
	 * @param	array		$extraParameters: Extra parameters to be passed to XSLT.
	 * @param	array		$altParams: The alternative parameters to be called with the function.
	 * @param	boolean		$useAlt: If true, the $altParams will be used.
	 * @return	string		The output from XSLT.
	 */
	public function transformOutput($function, array $priParams, $template, array $extraParameters = array(), array $altParams = array(), $useAlt = false)
	{
		if(!$template)
			return '';

		$params = $priParams;
		if ($useAlt && !empty($altParams))
			$params = $altParams;
		//First try cache:
        $cachedData = $this->pi->getCachedData(array($this->pi->LLkey, $priParams, $GLOBALS['TSFE']->currentRecord, $this->pi->conf['list_max_size']), $template);
		if($cachedData && $cachedData['output'])
		{
			t3lib_div::devlog('Loaded cached data', $this->pi->extKey);

			//$this->noindexoutput = $cachedData['noindex'];
			//$this->redirect = $cachedData['redirect'];
            if ($cachedData['noindex'])
                $this->pi->insertNoIndex();
            if ($cachedData['redirect'])
                $this->pi->makeRedirect();
            $this->pi->setLastResultCount(intval($cachedData['resultCount']));

			return $cachedData['output'];
		}
		else
		{
			$rest = new tx_pure_rest($this->pi->pureUrl, $this->pi);
			$xmlDoc = $rest->callFunction($function, $params);
		}

		if($xmlDoc == null)
		{
			return $this->displayError($this->pi->pi_getLL('pureErrorDownMessage'));
		}
		$xp = new DOMXPath($xmlDoc);

		$count = $xp->evaluate('number(//core:count)');
        $this->pi->setLastResultCount($count);
		if($count == 0)
		{
			if($xmlDoc->getElementsByTagName('count')->length == 0)
			{
				$count = 1;
			}
		}
		if ($count == 0)
		{
			if (!empty($altParams) && !$useAlt)
			{
				return $this->transformOutput($function, $priParams, $template, $extraParameters, $altParams, true);
			}
			return '';
		}
		else
		{
			//Limit count by list_max_size, which will limit the pager.
			if($this->pi->conf['list_max_size'] && intval($this->pi->conf['list_max_size']) < $count)
				$count = intval($this->pi->conf['list_max_size']);

			//Add browser links to the tree:
			if ($this->pi->internal['results_at_a_time']
				&& $this->pi->internal['results_at_a_time'] < $count)
			{
				$extraParameters['browse_links'] = $this->pi->list_browseresults($count);
			}
		}

		$noindex = $this->dontHaveOrganisationIds($xp, $this->pi->conf['index_organisationId']);
		$redirect = $this->dontHaveOrganisationIds($xp, $this->pi->conf['noredirect_organisationId']);

        //Set 'global' variables
        if ($noindex)
            $this->pi->insertNoIndex();
        if ($redirect)
            $this->pi->makeRedirect();

		//Find template file:
		$XSL = new DOMDocument();
		$XSLTName = t3lib_div::getFileAbsFileName('EXT:pure/res/templates/'.$template.'.xsl'); //TODO: make configurable.
		$succes = @$XSL->load( $XSLTName, LIBXML_COMPACT);

		if($XSL == null || !$succes)
		{
			t3lib_div::devlog('XSLT was not loaded. Check the file.', $this->pi->extKey, 2,  array('file' => $XSLTName, 'function' => $function, 'params' => $priParams));
			return $this->displayError($this->pi->pi_getLL('pureErrorTransfomationMessage'));
		}

		$transformedXML = $this->transformXmlWithXsl($xmlDoc, $XSL, $extraParameters);
		if($transformedXML == null)
		{
			t3lib_div::devlog(microtime(). 'Could not transform output with XSLT.', $this->pi->extKey, 2,  array('file' => $XSLTName));
			return $this->displayError($this->pi->pi_getLL('pureErrorTransfomationMessage'));
		}

		//Clean up the "xhtml" . Removing empty string tags etc.
		$XSLCleanup = new DOMDocument();
		$XSLCleanupName = t3lib_div::getFileAbsFileName('EXT:pure/res/templates/Cleanup.xsl');
		$succes = @$XSLCleanup->load( $XSLCleanupName, LIBXML_COMPACT);
		if($succes)
		{
			//Another way, instead of saving and loading xml?
			@$transformedXML->loadXML($transformedXML->saveXML());
			$transformedXML = $this->transformXmlWithXsl($transformedXML, $XSLCleanup);
		}

		$result = '';
		/*foreach($transformedXML->childNodes as $node)
		{
			$out = $transformedXML->saveXML($node);
			$result .= $out."\n";
		}*/
		$result = $transformedXML->saveXML($transformedXML->documentElement, LIBXML_NOXMLDECL);

		if($cachedData == NULL && $result)
		{
			$cacheArray = array();
			$cacheArray['output'] = $this->pi->appendPureDiv($result);
			$cacheArray['noindex'] = $noindex;
			$cacheArray['redirect'] = $redirect;
			$cacheArray['resultCount'] = $count;
			$this->pi->insertCachedData(array($this->pi->LLkey, $priParams, $GLOBALS['TSFE']->currentRecord, $this->pi->conf['list_max_size']), $template, $cacheArray);
			if ($useAlt)//Cache the primary to the same data:
				$this->pi->insertCachedData(array($this->pi->LLkey, $altParams, $GLOBALS['TSFE']->currentRecord, $this->pi->conf['list_max_size']), $template, $cacheArray);

		}

		return $this->pi->appendPureDiv($result);
		//exit;
		//return utf8_decode($result);
	}


    protected function getOrganisationPath()
    {
        return '';
    }

    /**
	 * Return true, if the none organisations with the xpath $xp can be found with organisationId equal $organisation.
	 *
	 * @param	object		$xp: The DOMXPath to use.
	 * @param	array		$organisation: A comma sepearated list of organisationIds.
	 * @return	boolean		Return true, if the none organisations with the xpath $xp can be found with organisationId equal $organisation.
	 */
	private function dontHaveOrganisationIds($xp, $organisation)
	{
		$organisationIds = array();
		$organisationIdsString = explode(',', $organisation);

		foreach($organisationIdsString as $orgString)
		{
			$org = intval($orgString);
			if($org)
			{
				$organisationIds[] = $org;
			}
		}

		$predicates = array();
		foreach($organisationIds as $org)
		{
			$predicates[] = 'organisation:organisationId = \''.$org.'\'';
		}

        $orgPath = $this->getOrganisationPath();
        if ($orgPath) {
            $predicate = implode(' or ', $predicates);
            return count($organisationIds) > 0
				&& $xp->evaluate('count(' . $orgPath . '['.$predicate.']) = 0');
        }
        return TRUE;
	}


    /**
	 * Tranform the XML, $xmlDoc, with the XSLT, $xslDoc.
	 *
	 * @param	object		$xmlDoc: The input XML document.
	 * @param	object		$xslDoc: The XSLT document to use.
	 * @param	array		$extraParameters: Extra parameters that are passed to the XSLT.
	 * @return	object		The output of the transformation.
	 */
	private function transformXmlWithXsl($xmlDoc, $xslDoc, $extraParameters = array())
	{
		/*************Make output********************/
		$xslt = new XSLTProcessor();
		$xslt->importStylesheet( $xslDoc );

		//Set grouping parameters
		if (is_array($extraParameters))
		{
			foreach($extraParameters as $k => $param)
			{
				$xslt->setParameter('', $k, $param);
			}
		}
		//Set the localization language
		$xslt->setParameter(self::$pureNamespace, 'lang', $this->pi->LLkey);
        $xslt->setParameter(self::$pureNamespace, 'locale', $this->pi->pi_getLL('locale'));
		//$xslt->setParameter(self::$pureNamespace, 'prilang', $this->pi->conf['pure_primary_lang']);

		$xslt->setParameter(self::$pureNamespace, 'pureSinglePidUrl', $this->pi->pi_linkTP_keepPIvars_url(array(), false, true, $this->pi->conf['singlePid']));

		//Set the pureUrl
		$xslt->setParameter('', 'pureUrl', $this->pi->pureUrl);

		$xslt->registerPHPFunctions();
		$outputXML = $xslt->transformToDoc( $xmlDoc);
		return $outputXML;
	}

    /**
	 * Remove white spaces.
	 *
	 * @param	string		$str: The string.
	 * @return	string		The $str without white spaces.
	 */
	public function removeWhiteSpace($str)
	{
		return preg_replace('/\s/', '', $str);
	}


}

if (defined('TYPO3_MODE') && $TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['ext/pure/pi/class.tx_pure_pi_base.php'])	{
	include_once($TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['ext/pure/pi/class.tx_pure_pi_base.php']);
}


?>
