<?php
/***************************************************************
 *  Copyright notice
 *
 *  (c) 2009-2010 Mads Sandberg Brun <msb@cs.au.dk>
 *  (c) 2009-2010 Peter Sandberg Brun <psb@cs.au.dk>
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/
/**
 * [CLASS/FUNCTION INDEX of SCRIPT]
 *
 *
 *
 */
require_once(t3lib_extMgm::extPath('pure').'pi/class.tx_pure_pi_base.php');
/**
 * Persons controller for the 'pure' extension.
 *
 * @author	Mads Sandberg Brun <msb@cs.au.dk>
 * @author	Peter Sandberg Brun <psb@cs.au.dk>
 * @package	TYPO3
 * @subpackage	tx_pure
 */
class tx_pure_pi_persons extends tx_pure_pi_base{


    public function displaySingle(array $displayConfig, $templateName)
	{
        return $this->displayList($displayConfig, $templateName);
    }
    
	/**
	 * Displays multiple persons
	 * The $displayConfig have the following keys:
	 * 		personId: A commaseperated list on persons ids.
	 * 		orgId:
	 * 		keywordId:
	 * 		state:
	 * 		type:
	 * 		light:
	 * 		sort:
	 * 		ascDesc:
	 * 		foldOutFirstTab:
	 * 		tabIndexToOpen:
	 *
	 * @param	array		$displayConfig: The configuration array with the following options used.
	 * @param	string		$templateName: The name of the template to use.
	 * @param	string		$search: Search input.
	 * @return	string		The output from the template. Etc. HTML.
	 */
	public function displayList(array $displayConfig, $templateName,  $search = '')
	{

        //fix PURE4 sorings
        $displayConfig['sort'] = str_replace('firstname', 'firstName', $displayConfig['sort']);
        $displayConfig['sort'] = str_replace('lastname', 'lastName', $displayConfig['sort']);


		$displayConfig['personEmployeeIds'] = $this->removeWhiteSpace($displayConfig['personEmployeeIds']);
		if(!$displayConfig['orgId'] && !$displayConfig['personEmployeeIds'] && !$displayConfig['personId'] && !$search && !$displayConfig['keywordId'])
			return $this->displayNothing();

		if (!$displayConfig['state'])
			$displayConfig['state'] = 'active';

		
		//$this->pi->personType = $displayConfig['type'];

		$parray=array(
				'rendering' => $displayConfig['light'] ? "xml_short" : "xml_long",
				'window.offset' => "0",
				'window.size' => "-1",
		);
		if ($displayConfig['orgId'])
		{
			$parray['associatedOrganisationUuids.uuid'] = $displayConfig['orgId'];
		}
		if ($displayConfig['sort'])
		{
			$parray['orderBy.property[0]'] = $displayConfig['sort']; //Valid: created, firstName, id, lastName, modified
			$parray['orderBy.property[0].descending'] = ($displayConfig['ascDesc'] === 'asc' ? 'false' : 'true');
		}

		if ($displayConfig['state'] !== 'both')//Remove if both.
			$parray['state'] = $displayConfig['state'];

		if ($search)
		{
			$parray['searchString'] = $search;
		}
		else
		{
			if ($displayConfig['personId']) {
				$parray['uuids.uuid'] = $displayConfig['personId'];
            }
            if ($displayConfig['personEmployeeIds']) {
                $parray['personEmployeeIds.value'] = $displayConfig['personEmployeeIds'];
            }
            
            if ($displayConfig['type'])
                $parray['employmentClassificationUris.uri'] = $displayConfig['type'];

            if ($displayConfig['keywordId'])
                $parray['keywordClassificationUris.uri'] = $displayConfig['keywordId'];
		}

		$function = 'persons';
		$extraParameters = array();
		$extraParameters['foldOutFirstTab'] = $displayConfig['foldOutFirstTab'] ? 'true' : 'false';
		$extraParameters['tabIndexToOpen'] = $displayConfig['tabIndexToOpen'];
        $extraParameters['hideJobtitleInList'] = $this->pi->conf['hideJobtitleInList'] ? true : false;

		return $this->transformOutput($function, $parray, $templateName, $extraParameters );
	}


	public function displayImage($imageId, $width, $height)
	{
		$cacheTime = 7 * 24 * 60 * 60; //Save for a week.
		//Get image url, using pureUrl
		$url = 'http://pure3a.au.dk:8080/ws/fbspretrieve/'.$imageId;

		$image = new tx_pure_image();

		$image_path = htmlspecialchars($url);
		$image_path = str_replace('/', '', $image_path);
		$image_path = str_replace(':', '', $image_path);
		$image_path = PATH_site.'/typo3temp/pure/'.$image_path;

		//Check cache
		if (file_exists($image_path) && time() - filemtime($image_path) < $cacheTime)
		{
			$image->load($image_path);
		}//Check for unknown image type cache
		else if (file_exists($image_path. 'unknown') && time() - filemtime($image_path. 'unknown') < $cacheTime)
		{
			$image->image_url = $url;
			$image->image = null;
		}
		else
		{
			$image->load($url);

			$new_folder = t3lib_div::dirname($image_path);
			if (!is_dir($new_folder)) {
				mkdir ($new_folder);
			}
			if ($image->image == null)
			{
				$tagFile = fopen($image_path. 'unknown', 'w');
				fclose($tagFile);
			}
			else
			{
				$image->output($image_path);
			}
		}
		$image->resize($width, $height, true);
		$image->output();
		imagedestroy($image->image);
		Header('Cache-Control: public, max-age=' . $cacheTime);
	}

    /**
	 * Displays a list of persons followed by a list of keyword, that are subkeywords of $keyword
     * 
	 * TODO: Uris with comma not working. Should be fixed by Atira.
     * see: http://pure4p.au.dk/ws/rest/persons?rendering=xml_long&window.offset=0&window.size=10&keywordClassificationUris.uri=/dk/atira/pure/core/keywords/Kunst,KulturOgMedier&requestOptions.serializeRequest=true&
     * @param	string		$keywordUri: The keyword uri
	 * @return	string		XHTML.
	 */
	public function displayKeywordPage($keywordUri)
	{
        if(!$keywordUri)
			return $this->displayNothing();

		$parray=array(
                'baseUri' => '/dk/atira/pure/core/keywords'
		);

		$keywordTemplate = $this->pi->conf['templates.']['singlePidsTemplates.']['keyword_keyword'];
		$extraParameters = array( 
            'rootClassificationUri' => $keywordUri
            );
		$keywordOutput = $this->transformOutput('classificationschemehierarchy', $parray, $keywordTemplate, $extraParameters );

        /*

		//Find all keywordId under this keyword, so every person under the given keyword is found.
		$parray=array(
				'parentIds' => $keyword,
				'levels' => "-1", //All levels
		);
		$rest = new tx_pure_rest($this->pi->pureUrl);
		$subKeywordXml = $rest->callFunction('getKeywords', $parray);

		$ids = array(intval($keyword));
		$xp = new DOMXPath($subKeywordXml);
		$idElements = $xp->query('//id');
		foreach($idElements as $idElement){
			$ids[] = intval($idElement->textContent);
		}

		unset($subKeywordXml);*/

        //TODO: Find subkeywordUris for PURE4.
        //(http://pureserver.daimi.au.dk/ws/rest/classificationschemehierarchy?baseUri=/dk/atira/pure/core/keywords)

		$personDisplayConfig = array();
		//Find the persons
		$personDisplayConfig['keywordId'] = $keywordUri; //implode(',', $ids); 
    	$personDisplayConfig['light'] = true; //We only use persons names
    	$personDisplayConfig['sort'] = 'firstname';
    	$personDisplayConfig['ascDesc'] = 'asc';

		$personTemplate = $this->pi->conf['templates.']['singlePidsTemplates.']['keyword_persons'];
		$persons = $this->displayList($personDisplayConfig, $personTemplate);

		return $persons . $keywordOutput;

	}

	/**
	 * Displays a search form for persons.
	 *
	 * @param	string		$resultTemplate: The template to use for the results. (Person template)
	 * @param	string		$formTemplate: The template to use for the searh form.s
	 * @param	string		$orgIds: The organisationids, that can be searched within.
	 * @param	boolean		$onlyResult: If true, only shows the result.
	 * @param	integer		$resultPage: The pageId to redirect to search on submit.
	 * @param	boolean		$onlyForm: If true, only shows the search form.
	 * @return	string		XML.
	 */
	public function displaySearch($resultTemplate, $formTemplate, $orgIds, $onlyResult, $resultPage, $onlyForm)
	{
		$content = '';
		$displayConfig = array();
		$displayConfig['sort'] = 'firstname';
		$displayConfig['state'] = 'active';
		$displayConfig['ascDesc'] = 'asc';
		if (isset($this->pi->piVars['organisationIds']))
			$displayConfig['orgId'] = htmlspecialchars($this->pi->piVars['organisationIds']);
		else
			$displayConfig['orgId'] = $orgIds;

		$seachValue = htmlspecialchars($this->pi->piVars['sword']);
		//Get the result with the given template to use for the results
		$result = '';
		if ($seachValue && !$onlyForm)
			$result = $this->displayList($displayConfig, $resultTemplate, $seachValue);
		if ($onlyResult)
			$content .= $result;
		else
		{
			$extraElement = array();
			//Prepare for search template
			$extraElement[] = new DOMElement('organisationIdsToChoose', $orgIds);

			$content .= $this->displaySearchFormXSLT($formTemplate, $result, $extraElement, $resultPage );

		}
		return $content;
	}

    /**
	 * Display keywords for a given person.
	 * The $displayConfig have the following keys:
	 * 		personId: The person id.
	 * @param	array		$displayConfig: The configuration array with the following options used.
	 * @param	string		$templateName: The template to use for the output.
	 * @return	string
	 */
	public function displayKeywords(array $displayConfig, $templateName)
	{
		//$personId = $this->getPersonIdFromPersonnelId($displayConfig['personId']);
        if(!$displayConfig['personId'])
			return $this->displayNothing();
        
		$parray=array(
				'uuids.uuid' => $displayConfig['personId']
		);

		$function = 'keywordsfromperson';
		$extraParameters = array();
        $hookParams = array();
		return $this->transformOutput($function, $parray, $templateName, $extraParameters );
	}


    protected function getOrganisationPath() {
        return '//core:result/core:content[1]/person:organisationAssociations/person:organisationAssociation/person:organisation';
    }

	

}

if (defined('TYPO3_MODE') && $TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['ext/pure/pi/class.tx_pure_pi_persons.php'])	{
	include_once($TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['ext/pure/pi/class.tx_pure_pi_persons.php']);
}


?>
