<?php
/***************************************************************
 *  Copyright notice
 *
 *  (c) 2009-2010 Mads Sandberg Brun <msb@cs.au.dk>
 *  (c) 2009-2010 Peter Sandberg Brun <psb@cs.au.dk>
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/
/**
 * [CLASS/FUNCTION INDEX of SCRIPT]
 *
 *
 *
 */
require_once(t3lib_extMgm::extPath('pure').'pi/class.tx_pure_pi_base.php');
/**
 * Publications controller for the 'pure' extension.
 *
 * @author	Mads Sandberg Brun <msb@cs.au.dk>
 * @author	Peter Sandberg Brun <psb@cs.au.dk>
 * @package	TYPO3
 * @subpackage	tx_pure
 */
class tx_pure_pi_publications extends tx_pure_pi_base{
    //http://pure4p.au.dk/ws/rest/allowedformats?type=dk.atira.pure.api.shared.model.base_du.publication.Publication
    //BIBTEX format?


    /**
	 * Displays a single publication.
	 * The $displayConfig have the following keys:
	 * 		pubId: The publication id.
	 *
	 * @param	array		$displayConfig: The configuration array with the following options used.
	 * @param	string		$templateName: The name of the template to use.
	 * @return	string		The output from the template. Etc. HTML.
	 */
	public function displaySingle(array $displayConfig, $templateName)
	{
		if(!$displayConfig['pubId'])
			return $this->displayNothing();

		$parray=array(
				'uuids.uuid' => $displayConfig['pubId'],
				'rendering' => "xml_long",
				'window.offset' => "0",
				'window.size' => "1",
				'hideExternalPublications' => 'false'
		);
		$extraParameters = array();
		return $this->transformOutput('publications', $parray, $templateName, $extraParameters);

	}


    /**
	 * Displays multiple publications.
	 * The $displayConfig have the following keys:
	 * 		personId: A commaseperated list on persons ids.
	 * 		pubIds:
	 * 		orgId:
	 * 		size:
	 * 		groupby:
	 * 		groupby2:
	 * 		ascDesc:
	 * 		pubsort:
	 * 		submittedyear:
	 * 		selectedByPersons:
	 * 		publicationTypes:
	 * 		publicationCategories:
	 *
	 * @param	array		$displayConfig: The configuration array with the following options used.
	 * @param	string		$templateName: The name of the template to use.
	 * @param	string		$search: Search input.
	 * @return	string		The output from the template. Etc. HTML.
	 */
	public function displayList(array $displayConfig, $templateName, $search = '')
	{
        
		$rssUrl = htmlentities(t3lib_div::getIndpEnv('TYPO3_SITE_URL'). $this->pi->pi_linkTP_keepPIvars_ajax_id_url( array( 'pointer' => null, 'showType' => 'pubrss') , $this->pi->allowCaching));
		$GLOBALS['TSFE']->additionalHeaderData['pure-pubrss']
			= '<link rel="alternate" type="application/rss+xml" title="Publications - '.$GLOBALS['TSFE']->page['title'].'" href="'.$rssUrl.'" />';

		$size = intval($displayConfig['size']);
		if (!$size)
			$size = $this->pi->conf['list_size'];
		$this->pi->internal['results_at_a_time'] = $size;

		//set pointer
		$page = intval($this->pi->piVars['pointer']);
		if ($this->pi->config['showType'] == 'pubrss')
			$page = 0; //Always at page 0.
		else if (!$this->pi->config['userclick'] && $_COOKIE["au-publication-pointer"] && !isset($this->pi->piVars['pointer']))
			$page = intval($_COOKIE["au-publication-pointer"]); //Use the cookie pointer, if page auto loaded.
		else if($this->pi->piVars['pubsort'] && $_COOKIE["au-publication-sort"] && $this->pi->piVars['pubsort'] != $_COOKIE["au-publication-sort"])
			$page = 0; //Reset pointer to 0, if user chossed new ordering.

		//Set the pointer if, userclick.
		if ($this->pi->config['userclick'])
			setcookie("au-publication-pointer", $page, $page ? $this->pi->cookie_time : 0);

		$this->pi->piVars['pointer'] = $page;

		if ($this->pi->config['showType'] != 'pubrss')
		{
			if($this->pi->piVars['pubsort'] || $_COOKIE["au-publication-sort"])
			{
				$displayConfig['pubsort'] = $this->pi->piVars['pubsort'] ? $this->pi->piVars['pubsort'] : $_COOKIE["au-publication-sort"];

				//If no grouping, set defualt sortings:
				if (!$displayConfig['groupby'] && !$displayConfig['groupby2'])
				{
					if (strtolower($displayConfig['pubsort']) === 'publicationyear' 
                            || strtolower($displayConfig['pubsort']) === 'submittedYear'
                            || strtolower($displayConfig['pubsort']) === 'created')
						$displayConfig['ascDesc'] = 'desc';
					else if (strtolower($displayConfig['pubsort']) === 'authorlastname'
						|| strtolower($displayConfig['pubsort']) === 'title')
						$displayConfig['ascDesc'] = 'asc';
				}

				//Save cookie
				setcookie("au-publication-sort", $displayConfig['pubsort'], $this->pi->cookie_time);

			}
			else if ( strtolower($displayConfig['pubsort']) === '')
			{
				$displayConfig['pubsort'] = 'publicationYear';
				if (!$displayConfig['groupby'] && !$displayConfig['groupby2'])
					$displayConfig['ascDesc'] = 'desc';
			}
		}
        
		//Set it descending
		if ($displayConfig['pubsort'] == 'publicationYear' && !$displayConfig['ascDesc'])
			$displayConfig['ascDesc'] = 'desc';

		$displayConfig['personEmployeeIds'] = $this->removeWhiteSpace($displayConfig['personEmployeeIds']);

		//Is there something to show at all?
		if(!$displayConfig['orgId'] && !$displayConfig['personEmployeeIds'] && !$displayConfig['personId'] && !$displayConfig['pubIds'] && !$search)
			return $this->displayNothing();

		if ($displayConfig['groupby'] === $displayConfig['groupby2'] )
			$displayConfig['groupby2'] = '';

		if ($displayConfig['submittedyear'] === '0')
			$displayConfig['submittedyear'] = '';

		$submittedYearStart = $displayConfig['submittedyear'];
		$submittedYearEnd = '';
		if ($displayConfig['submittedyear'])
		{
			$submitted = explode('-',$displayConfig['submittedyear'] );
			if (count($submitted) > 1)
			{
				$submittedYearStart = $submitted[0];
				$submittedYearEnd = $submitted[1];
			}
		}
        
		if($this->pi->piVars['sortdirection'])
			$displayConfig['ascDesc'] = htmlentities($this->pi->piVars['sortdirection']);

		//Setup selected.
		if (!isset($this->pi->piVars['showAll']))
			$this->pi->piVars['showAll'] = $displayConfig['selectedByPersons'] ? 'false' : 'true';
		//$selected = $this->pi->piVars['showAll'] == 'true' ? 'false' : 'true';
		//if ( $this->pi->config['showType'] == 'pubrss')
		//	$selected = 'false';
		$parray=array(
				 'rendering' => "xml_long",
				'window.offset' => $size*$page,
				'window.size' => $size,
				'hideExternalPublications' => 'false',

		//TODO: PURE4:
				//typeClassificationUris.uri
			//'publicationTypes' => $displayConfig['publicationTypes'], //Limit to publications types
				
				//Categories not any more. 
				//Now uses types defined in http://wiki.atira.dk/display/PURECUSTINFO/Specification+of+Pure+3+to+Pure+4+conversion+%28Danish+Universities%29
				//'publicationCategories' => $displayConfig['publicationCategories'] //Limit to publications types
				);


        //PURE 3 -> 4
        $searchOrder = array('publicationCategory','publicationType', 'submittedYear');
        $replacementOrder = array('typeClassification','typeClassification','submissionYear');
        
        $groupbyOrder = str_replace($searchOrder, $replacementOrder, $displayConfig['groupby']);
        $groupbyOrder2 = str_replace($searchOrder, $replacementOrder, $displayConfig['groupby2']);
        
        $orderBy = array();
        if ($groupbyOrder)
        {
            $orderBy[$groupbyOrder]  = array( 'name' => $groupbyOrder,
                               'descending' => ($groupbyOrder == 'publicationYear') || ($groupbyOrder == 'submissionYear') ? 'true' : 'false');
        }
        if ($groupbyOrder2)
        {
            $orderBy[$groupbyOrder2]  = array( 'name' => $groupbyOrder2,
                               'descending' => ($groupbyOrder2 == 'publicationYear') || ($groupbyOrder2 == 'submissionYear') ? 'true' : 'false');
        }

        $orderings = explode(',', $displayConfig['pubsort']);
        $first = true;
        if (!empty($orderings))
        {
            foreach($orderings as $order)
            {
                if (!$order)
                    continue;
                $orderBy[$order]  = array( 'name' => $order,
                                            'descending' => 'false');
                if ($first)
                {
                    $orderBy[$order]['descending'] = ($displayConfig['ascDesc'] === 'asc' ? 'false' : 'true');
                    $first = false;
                }
                
            }
        }

        //Build orderBy.property array
        $index = 0;
        foreach($orderBy as $order)
        {
            $parray['orderBy.property['.$index.']'] = $order['name'];
            $parray['orderBy.property['.$index.'].descending'] = $order['descending'];
            $index++;
        }
			//$parray['orderBy.property[0]'] = $ordering;
            //Valid: created, doi, id, lowertitle, modified, publicationDate, publicationYear, submissionYear, title,typeClassification

		if ($displayConfig['orgId'])//associatedOrganisationUuids.uuid or associatedOrganisationOrganisationIds.value or owningOrganisationUuids
			$parray['owningOrganisationUuids.uuid'] = 	$displayConfig['orgId'];
				
			//publicationDate.fromDate and publicationDate.toDate. PURE4: A DateTime (2011-01-01T00:00:00.000+01:00). Parsing year to arguments works fine
		if ($submittedYearStart)
			$parray['publicationDate.fromDate'] = $submittedYearStart;
		if ($submittedYearEnd)
			$parray['publicationDate.toDate'] = $submittedYearEnd;
			
		if ($search)							//searchString
			$parray['searchString'] = $search;
		else						
		{	
			if ($displayConfig['personId']) {
				$parray['associatedPersonUuids.uuid'] = $displayConfig['personId'];
            }
            if ($displayConfig['personEmployeeIds']) {
                $parray['associatedPersonEmployeeIds.value'] = $displayConfig['personEmployeeIds'];
            }

			if ($displayConfig['pubIds']) //pureInternalIds.id or uuids.uuid
				$parray['uuids.uuid'] = $displayConfig['pubIds'];
            if ($displayConfig['publicationTypes'])
                $parray['typeClassificationUris.uri'] = $displayConfig['publicationTypes'];
			
			//TODO: PURE 4: selectedByPersons do not exist?
			/*$parray = array_merge($parray, array(  
													//'selectedByPersons' => $selected, //Do not exist any more
			));*/
		}
//var_dump($parray);
		$function =  "publications"; //$search ? "queryPublications" : "publications";
		$altParray = array();
		//If not showAll, make alternativ uri, with not selectByPersons
		/*if ($this->pi->piVars['showAll'] == 'false' && !$search)
		{
			$altParray = $parray;
			$altParray['selectedByPersons'] = 'false';
		}*/
		$extraParameters = array();
		$extraParameters['pubsort'] = $displayConfig['pubsort'];
		$extraParameters['sortdirection'] = $displayConfig['ascDesc'];
		$extraParameters['group1'] = $displayConfig['groupby'];
		$extraParameters['group2'] = $displayConfig['groupby2'];
		$extraParameters['hide_rss'] = $search ? 'true' : 'false';
//var_dump($templateName);
		return $this->transformOutput($function, $parray, $templateName, $extraParameters, $altParray);
	}


    /**
	 * Displays a search form for publications.
	 *
	 * @param	string		$resultTemplate: The template to use for the results. (Publication template)
	 * @param	string		$formTemplate: The template to use for the searh form.s
	 * @param	string		$orgIds: The organisationids, that can be searched within.
	 * @param	boolean		$onlyResult: If true, only shows the result.
	 * @param	integer		$resultPage: The pageId to redirect to search on submit.
	 * @param	boolean		$onlyForm: If true, only shows the search form.
	 * @return	string		XML.
	 */
	public function displaySearch($resultTemplate, $formTemplate, $orgIds, $onlyResult, $resultPage, $onlyForm)
	{
		$content = '';

		$displayConfig = array();
		$displayConfig['pubsort'] = 'title';
		$displayConfig['size'] = 50;
		$displayConfig['submittedYearStart'] = htmlspecialchars($this->pi->piVars['submittedYearStart']);
		$displayConfig['submittedYearEnd'] = htmlspecialchars($this->pi->piVars['submittedYearEnd']);
		$displayConfig['submittedyear'] = $displayConfig['submittedYearStart'] . '-' .$displayConfig['submittedYearEnd'];
		$displayConfig['publicationCategories'] = htmlspecialchars($this->pi->piVars['publicationCategories']);
		$displayConfig['organisationIds'] = htmlspecialchars($this->pi->piVars['organisationIds']);
		$displayConfig['orgId'] = $displayConfig['organisationIds'];

		$seachValue = htmlspecialchars($this->pi->piVars['sword']);
		//Get the result with the given template to use the results
		$result = '';
		if ($seachValue && !$onlyForm)
			$result = $this->displayList($displayConfig, $resultTemplate, $seachValue);

		if ($onlyResult)
			$content .= $result;
		else
		{
			//Add extra search specific field to the form
			$extraElement = array();
			$extraElement[] = new DOMElement('organisationIdsToChoose', $orgIds);
			$extraElement[] = new DOMElement('selectedSubmittedYearStart', intval($displayConfig['submittedYearStart']));
			$extraElement[] = new DOMElement('selectedSubmittedYearEnd', intval($displayConfig['submittedYearEnd']));
			$extraElement[] = new DOMElement('selectedPublicationCategories', $displayConfig['publicationCategories']);
			$extraElement[] = new DOMElement('selectedOrganisationIds',  $displayConfig['organisationIds']);

			//Organisations
			$orgsDocument = $this->getOrganisationsNamesXML($orgIds);
            if ($orgsDocument->documentElement) {
                $extraElement[] =  $orgsDocument->documentElement;
            }

			$content .= $this->displaySearchFormXSLT($formTemplate, $result, $extraElement, $resultPage );
		}
		return $content;
	}

    protected function getOrganisationPath() {
        return '//core:result/core:content[1]/publication:organisations/organisation:organisation/organisation:organisationId';
    }
}

if (defined('TYPO3_MODE') && $TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['ext/pure/pi/class.tx_pure_pi_publications.php'])	{
	include_once($TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['ext/pure/pi/class.tx_pure_pi_publications.php']);
}


?>
