/*
Features/bugs that could be added/fixed:
    * Drag from views to Tree- that will delete item from store.
    * Bug: Do not show all of the Panel, when loaded on a hidden Tab. Current solution: Hidden panels.
*/

Ext.ns('TYPO3.PURE');

TYPO3.PURE.PureTreePanel = Ext.extend(Ext.Panel, {
    title: 'PureTreePanel',
    frame: true,
    collapsible: true,
    titleCollapse: true,
    height: 300,
    layoutConfig: { columns: 2 },

    //PureTreePanel fields
    includeStore: null,
    excludeStore: null,
    pureServerUrl: '',
    hiddenFieldName: '',
    ajaxID: '',
    hideExcluded: false,

    existInStores: function (id) {
        var exist = false;
        //Chech if it exist
        this.includeStore.each(function (record) {
            if (id == record.id) {
                exist = true;
                return false;
            }
            return true;
        });

        if (exist) {
            return true;
        }

        this.excludeStore.each(function (record) {
            if (id == record.id) {
                exist = true;
                return false;
            }
            return true;
        });

        return exist;
    },
    listeners: {
        /*afterrender : function (panel) {
            //alert("Test");
            //panel.doLayout(false, true);
        },*/
    },



    buildStoreViewPanel: function (store, name, orgPanel) {

        var listView = new Ext.ListView({
            store: store,
            ////////////////////////////////////////////////////////enableDD: true,
            multiSelect: true,
            //emptyText: 'No selected',
            reserveScrollOffset: true,
            columns: [{
                header: 'Name',
                dataIndex: 'name'
            }],
            style: 'background:#fff;'
        });

        var onDelete = function (btn, ev) {
            var indexes = listView.getSelectedIndexes();
            if (!indexes) {
                return;
            }
            Ext.each(indexes, function (index) {
                var rec = listView.store.getAt(index);
                listView.store.remove(rec);
            });
        };


        // put it in a Panel so it looks pretty
        var panel = new Ext.Panel({
            frame: true,
            //width: 300,
            //height: 100,
            layout: 'fit',
            //autoHeight: true,
            //autoWidth: true,
            title: name,
            items: listView,
            bbar: [{
                text: 'Remove',
                iconCls: 'pure-delete',
                handler: onDelete,
                scope: this
            }],

            listView: listView,

            listeners: {
                afterrender: function (p) {
                    var panelDropTarget = new Ext.dd.DropTarget(p.body.dom, {
                        //dropOK: false,
                        ddGroup: 'treeDDGroup',
                        notifyEnter: function (ddSource, e, data) {
                            //Add some flare to invite drop.
                            this.dropOK = !orgPanel.existInStores(data.node.id);
                            if (!this.dropOK)
                                return;
                            p.body.stopFx();
                            p.body.highlight();
                            return;
                        },
                        notifyDrop: function (ddSource, e, data) {

                            if (!this.dropOK) {
                                return true;
                            }

                            // create new record
                            var r = new p.listView.store.recordType(
                            {
                                name: data.node.text,
                                id: data.node.id
                            }, data.node.id);
                            p.listView.store.insert(0, r);
                            return true;
                        },
                        notifyOver: function (ddSource, e, data) {
                            return this.dropOK ? this.dropAllowed : this.dropNotAllowed;
                        }
                    });
                }
            }
        });
        //panel.addKeyListener(Ext.EventObject.DELETE, onDelete);
        return panel;
    },

    initComponent: function () {
        var panel = this;

        //Disable and wait for the tree children.
        panel.disable();

        panel.includeStore = new Ext.data.ArrayStore({
            fields: ['id', 'name'],
            idIndex: 0 // id for each record will be the first element
        });

        panel.excludeStore = new Ext.data.ArrayStore({
            fields: ['id', 'name'],
            idIndex: 0 // id for each record will be the first element
        });


        var tree = new Ext.tree.TreePanel(
                {
                    title: 'Hierarchy (Drag and drop)',
                    //width: 400,
                    //layout: 'fit',
                    //height: 300,
                    //autoWidth: true,
                    useArrows: false,
                    autoScroll: true,
                    animate: false,
                    enableDD: true,
                    ddGroup: 'treeDDGroup',
                    containerScroll: true,
                    rootVisible: false,
                    frame: true, //
                    name: 'tree',
                    root: {
                        nodeType: 'async'
                    },
                    draggable: false,

                    // auto create TreeLoader
                    //dataUrl: 'Json.aspx',

                    onAddToStore: function (store) {
                        //get selected from tree, and insert to store.
                        var index = tree.getSelectionModel().getSelectedNode();
                        if (!index) {
                            return;
                        }

                        if (panel.existInStores(index.id)) {
                            return;
                        }

                        // create new record
                        var r = new store.recordType(
                        {
                            name: index.text,
                            id: index.id
                        }, index.id);
                        store.insert(0, r);
                    },

                    listeners: {
                        //Avoid nodes being moved in the tree itself.
                        nodedragover: function (e) {
                            return false;
                        },
                        dblclick: function (node, e) {
                            tree.onAddToStore(panel.includeStore);
                        }
                    },

                    loader: new Ext.tree.TreeLoader({
                        timeout: 120000,
                        url: 'ajax.php',
                        baseParams: {
                            ajaxID: panel.ajaxID,//'tx_pure_pi::getPublicationTypesHiearchy', //getPublicationTypesHiearchy
                            pureserver: panel.pureServerUrl
                        },
                        preloadChildren: true
                        ,
                        listeners: {
                        load: function (loader, node, response) {

                            var rootNodes = Ext.decode(response.responseText);

                            var seachForName = function(nodes, id)
                            {
                                var nameFound = false;
                                Ext.each(nodes, function(node){
                                    if (node.id == id)
                                    {
                                        nameFound = node.text;
                                        return false; //Stop iteration
                                    }
                                    else if (node.children)
                                    {
                                        nameFound = seachForName(node.children, id);
                                        if (nameFound)
                                            return false; //Stop iteration
                                    }
                                    return true;
                                }
                                );
                                return nameFound;
                            };
                            
                            
                            //load stores here using hiddenfield and names from treeloader
                            //alert(response);
                            //getNodeById to find node element and therefor also name
                            var hiddenField = Ext.get(panel.hiddenFieldName);
                            if (hiddenField) {
                                var value = hiddenField.dom.value;

                                //Format: "included:excluded" or "inclueded"
                                var valueSplit = value.split(":", 2);
                                var included = valueSplit[0];
                                var excluded = '';
                                if (valueSplit.length > 1) {
                                    excluded = valueSplit[1];
                                }

                                var addElementToStore = function (store, ids) {
                                    for (var i = 0; i < ids.length; i++) {
                                        var id = ids[i];
                                        if (!id)
                                            continue;
                                        var name = "  Unknown  ";

                                        var nameFoundInTree = seachForName(rootNodes, id);
                                        if (nameFoundInTree)
                                            name = nameFoundInTree;

                                        // create new record
                                        var r = new store.recordType(
                                        {
                                            name: name,
                                            id: id
                                        }, id);
                                        store.insert(0, r);
                                    }
                                }
                                addElementToStore(panel.includeStore, included.split(","));
                                addElementToStore(panel.excludeStore, excluded.split(","));

                                //add Event listenere to the stores add event:
                                var changeEvent = function (store, records, index) {
                                    //Update hidden field with the value of the stores
                                    var value = "";
                                    var includeIds = [];
                                    var excludeIds = [];
                                    panel.includeStore.each(function (rec) {
                                        includeIds.push(rec.id);
                                    });
                                    panel.excludeStore.each(function (rec) {
                                        excludeIds.push(rec.id);
                                    });

                                    value = includeIds.join(',') + ":" + excludeIds.join(',');
                                    var hiddenField = Ext.get(panel.hiddenFieldName);
                                    if (hiddenField)
                                        hiddenField.dom.value = value;
                                };
                                panel.includeStore.on("add", changeEvent);
                                panel.excludeStore.on("add", changeEvent);

                                panel.includeStore.on("remove", changeEvent);
                                panel.excludeStore.on("remove", changeEvent);
                            }

                            panel.enable();
                        }
                        }
                    }),

                    bbar: {
                        xtype: 'toolbar',
                        items: [{
                            xtype: 'button',
                            text: 'Include',
                            iconCls: 'pure-add',
                            listeners: {
                                click: function () {
                                    tree.onAddToStore(panel.includeStore);
                                }
                            }
                        },
                                {
                                    xtype: 'button',
                                    text: 'Exclude',
                                    iconCls: 'pure-remove',
                                    listeners: {
                                        click: function () {
                                            tree.onAddToStore(panel.excludeStore);
                                        }
                                    },
                                    disabled: panel.hideExcluded
                                },
                                '-',
                                {
                                    xtype: 'tbtext',
                                    text: 'Filter: '
                                },
                                    {
                                        xtype: 'textfield',
                                        listeners: {
                                            render: function (c) {
                                                var textfield = this;

                                                //Used to cancel last defered function.
                                                var timeoutId = null;
                                                c.getEl().on('keyup', function () {
                                                    if (timeoutId)
                                                        clearTimeout(timeoutId);
                                                    //Defer call to wait for users full search.
                                                    timeoutId = tree.filterTree.defer(1000, this, [textfield.getValue()]);
                                                }, c);

                                                var keymap = new Ext.KeyMap(textfield.el, [
                                                    {
                                                        key:Ext.EventObject.ENTER ,
                                                        scope:this,
                                                        fn: function () {
                                                            if (timeoutId)
                                                                clearTimeout(timeoutId);
                                                            tree.filterTree(textfield.getValue());
                                                        }
                                                    },{
                                                        key:Ext.EventObject.ESC,
                                                        scope:this,
                                                        fn:function () {
                                                            if (timeoutId)
                                                                clearTimeout(timeoutId);
                                                            textfield.setValue('');
                                                            tree.filterTree(textfield.getValue());
                                                        }
                                                    }]);
                                                keymap.stopEvent = true;
                                            }
                                        }
                                    }
                            ]
                    }
                }
            );

        var treeFilter = new Ext.tree.TreeFilter(tree, {
            clearBlank: true,
            autoClear: true
        });


        tree.hasDescandents = function (n, re) {
            var str = false;
            n.cascade(function (n1) {
                if (re.test(n1.text)) {
                    str = true;
                    return;
                }
            });
            return str;
        };

        //Function to filter tree with.
        //Filter by the text given.
        tree.filterTree = function (text) {
            if (Ext.isEmpty(text, false)) {
                tree.collapseAll();
                treeFilter.clear();
                return;
            }


            var re = new RegExp(".*" + text + ".*", "i");

            //Calculate nodes to be showen. If af node is "okToShow" its parents
            // are "okToShow" also.
            var visitChild = function(n) {
                n.attributes.okToShow = undefined;
                if (re.test(n.text)) //Make text test.
                {
                    n.bubble(function (node) {//Bubble up to show parents.
                        if (node.attributes.okToShow) 
                            return false; //Stop bubbling
                        node.attributes.okToShow = true;
                        return true;
                    });
                }
                if (n.isExpandable())
                    n.expand(false, false); //Only children and no animation
                //childNodes or eachChild function can only
                //be used after calling n.expand(false, false);
                n.eachChild(visitChild);
            };
            //TODO: 8 seconds first time. Fast afterwards, 80-120ms.
//console.time("timing filter")
            visitChild(tree.root);
//console.timeEnd("timing filter")


            treeFilter.filterBy(function (node) {
                //console.log(node.text);
                return node.attributes.okToShow;
            });

        };


        // Add a sorter for tree
        new Ext.tree.TreeSorter(tree, { folderSort: true });

        var panelIncluded = panel.buildStoreViewPanel(this.includeStore, 'Included (All sub entries included)', panel);
        var panelExcluded = panel.buildStoreViewPanel(this.excludeStore, 'Excluded', panel);
        
        var storePanels = [panelIncluded];
        if (!panel.hideExcluded) {
            storePanels.push(panelExcluded);
        }

        //Span tree over two rows, so it are right to the other views.
        tree.rowspan = 2;
        Ext.apply(this,
            {
                defaults: {
                    flex: 1
                },
                layout:'hbox',
                
                layoutConfig: {
                    flex: 1,
                    align : 'stretch',
                    pack  : 'start'
                },
                items: [{
                    layout: 'vbox',
                    layoutConfig: {
                        align : 'stretch',
                        pack  : 'start'
                    },
                    width: 300,
                    defaults: {
                        flex: 1
                    },
                    items: storePanels
                }, tree]

            });
        //Call super
        TYPO3.PURE.PureTreePanel.superclass.initComponent.call(this);
    }
});

//Extend TreeLoader with timeout property.
Ext.tree.TreeLoader.override({
    requestData : function(node, callback){
        if(this.fireEvent("beforeload", this, node, callback) !== false){
            this.transId = Ext.Ajax.request({
                method:this.requestMethod,
                url: this.dataUrl||this.url,
                success: this.handleResponse,
                failure: this.handleFailure,
                timeout: this.timeout || 30000,
                scope: this,
                argument: {callback: callback, node: node},
                params: this.getParams(node)
            });
        }else{
            // if the load is cancelled, make sure we notify
            // the node that we are done
            if(typeof callback == "function"){
                callback();
            }
        }
    }
});

TYPO3.PURE.PersonTemplate = new Ext.XTemplate(
    '<tpl for="."><div class="search-item person-search-item">',
        '<tpl if="pictureUrl"><img class="person-search-item-picture" src="{pictureUrl}" /></tpl>',
        '<p class="person-search-item-name">{name}</p><p><strong>E-mail:</strong> {email}</p>',
        '<p><strong>WAYF ID:</strong> {id}</p>',
    '</div></tpl>'
);

TYPO3.PURE.DefaultTemplate = new Ext.XTemplate(
    '<tpl for="."><div class="search-item">',
        '<h4>{name}</h4>',
        '{id}',
    '</div></tpl>'
);

TYPO3.PURE.EntrySearchControl = Ext.extend(Ext.grid.GridPanel, {
    //header: false, //Do not show title.
    frame: true,
    collapsible: true,
    titleCollapse: true,
    //height: 300,
    //autoHeight: true,
    loadMask: true,
    
    viewConfig: {
        autoFill: true
        //forceFit: true
    },
    stripeRows: true,
    autoExpandColumn: 'name',

    store: null,
    pureServerUrl: '',
    hiddenFieldName: '',
    ajaxID: '',

    editMsgTitle: 'IDs',
    nameColumnTitle: 'Name',
    idColumnTitle: 'ID',
    itemSearchTemplate: TYPO3.PURE.DefaultTemplate,

    loadStore: function(value) {
        value = value.replace(/ /g, ',');
        value = value.replace(/\n/g, ',');
        
        if (value != "") {
            // trigger the data store load. Defer to get loading mask
            this.store.load.defer(1, this.store, [{params:{ids: value}}]);
        } else {
            this.store.removeAll();
            this.updateHiddenFieldValue(this.store);
        }
    },

    getHiddenValue: function() {
        var hiddenField = Ext.get(this.hiddenFieldName);
        if (hiddenField) {
            return hiddenField.dom.value;
        }
        return '';
    },

    parseVersionString: function  (str) {
        if (typeof(str) != 'string') { return false; }
        var x = str.split('.');
        // parse from string or default to 0 if can't parse
        var maj = parseInt(x[0]) || 0;
        var min = parseInt(x[1]) || 0;
        var pat = parseInt(x[2]) || 0;
        return {
            major: maj,
            minor: min,
            patch: pat
        }
    },

    updateHiddenFieldValue: function (store) {
        //Update hidden field with the value of the stores
        var value = "";
        var ids = [];
        store.each(function (rec) {
            ids.push(rec.id);
        });
        value = ids.join(',');
        var hiddenField = Ext.get(this.hiddenFieldName);
        if (hiddenField)
            hiddenField.dom.value = value;
    },

    initComponent: function () {
        var panel = this;

        //Add id and name coulmns
        this.columns = [];
        this.columns.push({
            id       : 'name',
            header   : panel.nameColumnTitle,
            sortable : true,
            dataIndex: 'name'
        });
        this.columns.push({
            header   : panel.idColumnTitle,
            sortable : true,
            dataIndex: 'id'
        });

        var versionDetail = this.parseVersionString(Ext.version)
        //Add remove button column based on ExtJS version.
        if (versionDetail.major >= 3 && versionDetail.minor >= 3) {
            //Add ExtJS 3.3 actioncolumn
            this.columns.push({ 
                xtype: 'actioncolumn',
                sortable : false,
                width: 50,
                items: [{
                    iconCls: 'pure-delete',
                    tooltip: 'Remove',
                    handler: function(grid, rowIndex, colIndex) {
                        grid.store.removeAt(rowIndex);
                    }
                }]
            });
        } else {
            //Use old renderer/button approach.
            this.columns.push({
                renderer: function(value, metaData, record, rowIndex, colIndex, store) {
                    var id = Ext.id();
                    var createRemoveButton = function(value, id, record, rowIndex, colIndex, store) {
                        new Ext.Button({
                            text: 'Remove',
                            iconCls: 'pure-delete',
                            handler :  function(btn, e) {
                                store.removeAt(rowIndex);
                            },
                            renderTo: id
                        });
                    };
                    createRemoveButton.defer(1, this, [value, id, record, rowIndex, colIndex, store]);
                    return('<div id="' + id + '"></div>');
                },
                sortable : false,
                width: 100,
                dataIndex: 'id' //Just some index, we are not using
            });
        }
        
        panel.store = new Ext.data.JsonStore({
            url: 'ajax.php',
            baseParams: {
                ajaxID: panel.ajaxID,
                pureserver: panel.pureServerUrl
            },
            
            listeners: {
                load : function (store, records, options) {
                    var idsRequested = options.params.ids.split(',');
                    Ext.each(records, function(rec){
                        idsRequested.remove(rec.id);
                    });
                    
                    // Foreach entry not found inject a temp rec with no name
                    Ext.each(idsRequested, function(entryId){
                        var rec = new store.recordType({
                                name: '---Entry with id \'' + entryId + '\' not found in PURE---',
                                id: entryId
                            }, entryId);
                        store.addSorted(rec);
                    });

                    panel.updateHiddenFieldValue(store);
                }
            },
            fields: ['name', 'id'] //Should now recors fields
        });

        //add Event listenere to the stores add event:
        var changeEvent = function (store, records, index) {
            panel.updateHiddenFieldValue(store);
        };
        panel.store.on("add", changeEvent);
        panel.store.on("remove", changeEvent);

        //Load init value from the hidden field.
        var value = panel.getHiddenValue();
        panel.loadStore(value);
        
        var search = new Ext.form.ComboBox({
            store: new Ext.data.JsonStore({
                url: 'ajax.php',
                baseParams: {
                    ajaxID: panel.ajaxID,
                    pureserver: panel.pureServerUrl
                }
            }),
            typeAhead: false,
            loadingText: 'Searching...',
            width: 300,
            listWidth: 600,
            resizable: true,
            pageSize:8,
            //hideTrigger:true,
            tpl: panel.itemSearchTemplate,
            itemSelector: 'div.search-item',
            onSelect: function(record){ // override default onSelect to do redirect
                // Add to store if not already in the store.
                if (panel.store.getById(record.id) == undefined) {
                    panel.store.addSorted(record);
                }
            },
            listeners: {
                render: function (c) {
                    var keymap = new Ext.KeyMap(this.el, [
                        {
                            key:Ext.EventObject.ENTER ,
                            scope:this,
                            fn: function () {
                            }
                        },{
                            key:Ext.EventObject.ESC,
                            scope:this,
                            fn:function () {
                                this.clearValue();
                            }
                        }]);
                    keymap.stopEvent = true;
                }
            }
        });

        var editButton = new Ext.Button({
            text: 'Edit raw value',
            handler: function(button, event) {
                    Ext.MessageBox.show({
                    title: panel.editMsgTitle,
                    msg: 'Enter IDs: (comma, space or line separated)',
                    width: 600,
                    height: 600,
                    buttons: Ext.MessageBox.OKCANCEL,
                    multiline: true,
                    value: panel.getHiddenValue(),
                    fn: function(buttonId, value) {
                        if (buttonId == 'ok') {
                            panel.loadStore(value);
                        }
                    }
                });
            }
        });

        Ext.apply(this,
            {
                bbar: new Ext.Toolbar({
                    items: ['Search: ', ' ', search, {xtype: 'tbspacer', width: 300}, '(Requires a minimum of 4 characters. )',
                        '->', editButton]
                })
            });
        //Call super
        TYPO3.PURE.EntrySearchControl.superclass.initComponent.call(this);
    }

});
