<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns="http://www.w3.org/1999/xhtml"
                xmlns:fn="http://www.w3.org/2005/02/xpath-functions"
                xmlns:regexp="http://exslt.org/regular-expressions"
                xmlns:date="http://exslt.org/dates-and-times"
                xmlns:ll="http://typo3.org/extensions/repository/view/pure/current/"
                xmlns:php="http://php.net/xsl"
                xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
                xmlns:str="http://exslt.org/strings"
                
                xmlns:core="http://atira.dk/schemas/pure4/model/core/stable"
                xmlns:publication="http://atira.dk/schemas/pure4/model/abstractpublication/stable"
                xmlns:person="http://atira.dk/schemas/pure4/model/abstractperson/stable"
                xmlns:extensions="http://atira.dk/schemas/pure4/model/extensions/stable"
                xmlns:organisation="http://atira.dk/schemas/pure4/model/abstractorganisation/stable"
                xmlns:event="http://atira.dk/schemas/pure4/model/abstractevent/stable"
                xmlns:publisher="http://atira.dk/schemas/pure4/model/abstractpublisher/stable"
                xmlns:stab="http://atira.dk/schemas/pure4/dk/model/publication/stable"
                xmlns:journal="http://atira.dk/schemas/pure4/model/abstractjournal/stable"
                xmlns:activity="http://atira.dk/schemas/pure4/model/abstractactivity/stable"
                
                exclude-result-prefixes="fn str regexp php ll date xsi core publication person extensions organisation event publisher stab journal activity">

  <xsl:import href="localization.xsl" />
  <xsl:param name="ll:localizationFile" select="'locallang_activity.xml'" />

  <xsl:output encoding="utf-8" />
  <xsl:param name="actsort" />
  <xsl:param name="pureUrl" select="'http://pure3a.au.dk:8080/ws/axis2/services/PureWebService/'" />
  <xsl:param name="browse_links" />

  <!-- Include grouping XSLT -->
  <xsl:include href="Group.xsl" />

  <xsl:template match="/">
    <div class="activities-simple">
      <div class="sorting pure-ajax-request">
        <p>
          <xsl:value-of select="ll:getLL('sortby')"/>
          <xsl:text> </xsl:text>
          <xsl:choose>
            <xsl:when test="$actsort = 'startDate'">
              <strong>
                <xsl:value-of select="ll:getLL('sortDate')"/>
              </strong>
            </xsl:when>
            <xsl:otherwise>
              <a href="{typo3/links/sortDateUrl}">
                <xsl:value-of select="ll:getLL('sortDate')"/>
              </a>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:text> | </xsl:text>
          <xsl:choose>
            <xsl:when test="$actsort = 'title'">
              <strong>
                <xsl:value-of select="ll:getLL('sortTitle')"/>
              </strong>
            </xsl:when>
            <xsl:otherwise>
              <a href="{typo3/links/sortTitleUrl}">
                <xsl:value-of select="ll:getLL('sortTitle')"/>
              </a>
            </xsl:otherwise>
          </xsl:choose>

          <xsl:if test="//request/personnelIds">
            <xsl:variable name="haveSelcted" select="php:function('tx_pure_xsltfunctions::haveSelectedByPersons', $pureUrl, 'getActivities', string(//request/personnelIds))" />
            <xsl:if test="$haveSelcted">
              <br />
              <xsl:value-of select="ll:getLL('showSelected')"/>
              <xsl:text> </xsl:text>
              <xsl:choose>
                <xsl:when test="//request/selectedByPersons = 'true'">
                  <a href="{typo3/links/allActivitiesUrl}">
                    <xsl:value-of select="ll:getLL('allSelected')"/>
                  </a>
                </xsl:when>
                <xsl:otherwise>
                  <strong>
                    <xsl:value-of select="ll:getLL('allSelected')"/>
                  </strong>
                </xsl:otherwise>
              </xsl:choose>
              <xsl:text> | </xsl:text>
              <xsl:choose>
                <xsl:when test="//request/selectedByPersons = 'true'">
                  <strong>
                    <xsl:value-of select="ll:getLL('selectedByPerson')"/>
                  </strong>
                </xsl:when>
                <xsl:otherwise>
                  <a href="{typo3/links/selectedActivitiesUrl}">
                    <xsl:value-of select="ll:getLL('selectedByPerson')"/>
                  </a>
                </xsl:otherwise>
              </xsl:choose>
            </xsl:if>
          </xsl:if>
        </p>
      </div>

      <div class="activities">
        <xsl:apply-templates select="." mode="group" />
      </div>

      <xsl:if test="$browse_links">
        <div class="browse-links pure-ajax-request">
          <p class="results_numbers">
            <xsl:value-of select="$browse_links" disable-output-escaping="yes"/>
          </p>
        </div>
      </xsl:if>

    </div>
  </xsl:template>

  <xsl:template name="list">
    <xsl:param name="items" />
    <ul class="au-smallsans">
      <xsl:for-each select="$items">
        <li>
          <xsl:apply-templates select="activity:personAssociation/activity:person" />
          <xsl:apply-templates select="activity:personAssociation/activity:personRole" />

          <i>
            <a href="{typo3/links/activityUrl}">
              <xsl:apply-templates select="activity:title" mode="localize" />
            </a>
          </i>
          
          <xsl:apply-templates select="." />
          
          <xsl:if test="activity:personAssociation/activity:startDate or activity:personAssociation/activity:endDate">
            <xsl:text>, </xsl:text>
            <xsl:choose>
              <xsl:when test="activity:personAssociation/activity:startDate and activity:personAssociation/activity:endDate 
                        and activity:personAssociation/activity:startDate/core:year = activity:personAssociation/activity:endDate/core:year
                        and activity:personAssociation/activity:startDate/core:month = activity:personAssociation/activity:endDate/core:month
                        and activity:personAssociation/activity:startDate/core:day = activity:personAssociation/activity:endDate/core:day">
                <xsl:value-of select="activity:personAssociation/activity:startDate/core:day"/>
                <xsl:text>.</xsl:text>
                <xsl:value-of select="activity:personAssociation/activity:startDate/core:month"/>
                <xsl:text>.</xsl:text>
                <xsl:value-of select="activity:personAssociation/activity:startDate/core:year"/>
              </xsl:when>
              <xsl:otherwise>
                <xsl:if test="activity:personAssociation/activity:startDate">
                  <xsl:value-of select="activity:personAssociation/activity:startDate/core:day"/>
                  <xsl:text>.</xsl:text>
                  <xsl:value-of select="activity:personAssociation/activity:startDate/core:month"/>
                  <xsl:text>.</xsl:text>
                  <xsl:value-of select="activity:personAssociation/activity:startDate/core:year"/>
                  <xsl:text>-</xsl:text>
                </xsl:if>
                <xsl:if test="activity:personAssociation/activity:endDate">
                  <xsl:value-of select="activity:personAssociation/activity:endDate/core:day"/>
                  <xsl:text>.</xsl:text>
                  <xsl:value-of select="activity:personAssociation/activity:endDate/core:month"/>
                  <xsl:text>.</xsl:text>
                  <xsl:value-of select="activity:personAssociation/activity:endDate/core:year"/>
                </xsl:if>
              </xsl:otherwise>
            </xsl:choose>
            <xsl:text>.</xsl:text>
          </xsl:if>
        </li>
      </xsl:for-each>
    </ul>
  </xsl:template>

  <!-- Owner-->
  <xsl:template match="activity:personAssociation/activity:person">
    <xsl:value-of select="person:name/core:lastName"/>
    <xsl:text>, </xsl:text>
    <xsl:value-of select="person:name/core:firstName"/>
    <xsl:text>, </xsl:text>
  </xsl:template>

  <xsl:template match="activity:personAssociation/activity:personRole">
    <xsl:apply-templates select="core:term" mode="localize" />
    <xsl:text>, </xsl:text>
  </xsl:template>

  <!--core:content[contains(core:type, 'ContributionToJournal')]-->
  <xsl:template match="//core:result/core:content">
    
  </xsl:template>

  <xsl:template match="//core:result/core:content[contains(core:type, 'Appearance')]">
    <xsl:if test="activity:mediumName">
      <xsl:text>, </xsl:text>
      <xsl:value-of select="activity:mediumName"/>
    </xsl:if>
  </xsl:template>


  <xsl:template match="//core:result/core:content[contains(core:type, 'Lecture')]">
    <xsl:if test="activity:subTitle">
      <xsl:text>, </xsl:text>
      <xsl:apply-templates select="activity:subTitle" mode="localize" />
    </xsl:if>
    <xsl:if test="activity:arranger">
      <xsl:text>, </xsl:text>
      <xsl:value-of select="activity:arranger"/>
    </xsl:if>
    
    <!--Conference inside event field-->
    <!--<xsl:if test="conferenceTitle">
      <xsl:text>, </xsl:text>
      <xsl:value-of select="conferenceTitle"/>
    </xsl:if>
    <xsl:if test="conferenceCity">
      <xsl:text>, </xsl:text>
      <xsl:value-of select="conferenceCity"/>
    </xsl:if>
    <xsl:if test="conferenceCountry">
      <xsl:text>, </xsl:text>
      <xsl:value-of select="conferenceCountry"/>
    </xsl:if>-->
  </xsl:template>

  <xsl:template match="//core:result/core:content[contains(core:type, 'Other')]">
    <xsl:if test="activity:city">
      <xsl:text>, </xsl:text>
      <xsl:value-of select="activity:city"/>
    </xsl:if>
    <xsl:if test="activity:specificCountry">
      <xsl:text>, </xsl:text>
      <xsl:apply-templates select="activity:specificCountry/core:term" mode="localize" />
    </xsl:if>
  </xsl:template>


  <!--Default-->
  <!--<xsl:template match="//core:result/core:content[@xsi:type]">
    <li>
      <xsl:apply-templates select="owner" />
      <i>
        <a href="{typo3/links/activityUrl}">
          <xsl:value-of select="ll:localize(title_pri, title_sec)"/>
        </a>
      </i>
    </li>
    <xsl:if test="date">
      <xsl:text>, </xsl:text>
      <xsl:value-of select="date"/>
    </xsl:if>
    <xsl:text>.</xsl:text>
  </xsl:template>-->

</xsl:stylesheet>