<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns="http://www.w3.org/1999/xhtml"
                xmlns:fn="http://www.w3.org/2005/02/xpath-functions"
                xmlns:regexp="http://exslt.org/regular-expressions"
                xmlns:ll="http://typo3.org/extensions/repository/view/pure/current/"
                
                xmlns:core="http://atira.dk/schemas/pure4/model/core/stable"
                xmlns:publication="http://atira.dk/schemas/pure4/model/abstractpublication/stable"
                xmlns:person="http://atira.dk/schemas/pure4/model/abstractperson/stable"
                xmlns:extensions="http://atira.dk/schemas/pure4/model/extensions/stable"
                xmlns:organisation="http://atira.dk/schemas/pure4/model/abstractorganisation/stable"
                xmlns:event="http://atira.dk/schemas/pure4/model/abstractevent/stable"
                xmlns:stab="http://atira.dk/schemas/pure4/dk/model/publication/stable"
                
                xmlns:str="http://exslt.org/strings" 
                exclude-result-prefixes="fn str regexp ll core publication person extensions organisation event stab">
  <xsl:import href="localization.xsl" />
  <xsl:param name="ll:localizationFile" select="'locallang_person.xml'" />
  <xsl:param name="hideJobtitleInList" />
  <xsl:output omit-xml-declaration="yes" encoding="utf-8"  />

  <xsl:template match="/">
    <div class="pure-simple-person" >
      <xsl:for-each select="//core:result/core:content">
        <div class="vcard pure-simple-person-single" >
           <xsl:if test="person:photos/core:file">
            <a href="{person:photos/core:file[1]/core:url}" title="{person:name/core:firstName} {person:name/core:lastName}">
                <img class="photo logo" src="{person:photos/core:file[1]/core:url}" alt="{person:name/core:firstName} {person:name/core:lastName}" />
              </a>
          </xsl:if>
<!--          <xsl:if test="imageLowres/url or imageHighres/url">
            <xsl:choose>
              Image
              <xsl:when test="imageLowres/url">
                <xsl:choose>
                  <xsl:when test="imageHighres/url">
                    <a href="{imageHighres/url}" >
                      <img class="photo logo" src="{imageLowres/url}" alt="{person:name/core:firstName} {person:name/core:lastName}" />
                    </a>
                  </xsl:when>
                  <xsl:otherwise>
                    <img class="photo logo" src="{imageLowres/url}" alt="{person:name/core:firstName} {person:name/core:lastName}" />
                  </xsl:otherwise>
                </xsl:choose>
              </xsl:when >
              <xsl:otherwise>
                <a href="{imageHighres/url}" >
                  <img class="photo logo" src="{imageHighres/url}" alt="{person:name/core:firstName} {person:name/core:lastName}" />
                </a>
              </xsl:otherwise>
            </xsl:choose>
          </xsl:if>-->
          <h3 class="fn">
            <a href="{typo3/links/personUrl}">
              <span class="given-name">
                <xsl:value-of select="person:name/core:firstName"/>
              </span>
              <xsl:text>&#160;</xsl:text>
              <span class="family-name">
                <xsl:value-of select="person:name/core:lastName"/>
              </span>
            </a>
          </h3>

          <xsl:variable name="primaryOrganisation" select="person:organisationAssociations/person:organisationAssociation[not(person:period/extensions:endDate)][1]" />

          <xsl:if test="not($hideJobtitleInList)">
              <span class="title">
                <xsl:apply-templates select="$primaryOrganisation/person:jobTitle/core:term" mode="localize" />
              </span>
          </xsl:if>
          <br/>
          
          <xsl:apply-templates select="$primaryOrganisation/emailLink" />

          <xsl:apply-templates select="$primaryOrganisation/person:address/extensions:room" />
          <xsl:apply-templates select="$primaryOrganisation/person:phone" />

        </div>
      </xsl:for-each>
    </div>
  </xsl:template>

  
  <xsl:template match="//core:result/core:content/person:organisationAssociations/person:organisationAssociation/person:phone">
    <strong>
      <xsl:value-of select="ll:getLL('tel')"/>
      <xsl:text>: </xsl:text>
    </strong>
    <span class="tel">
      <xsl:choose>
        <xsl:when test="string-length(.)=8">
          <xsl:value-of select="ll:getLL('phoneprefix.DK')"/>
          <xsl:value-of select="substring(.,1,4)"/>
          <xsl:text> </xsl:text>
          <xsl:value-of select="substring(.,5,4)"/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of select="."/>
        </xsl:otherwise>
      </xsl:choose>
    </span>
    <br />
  </xsl:template>

  <xsl:template match="//core:result/core:content/person:organisationAssociations/person:organisationAssociation/emailLink">
    <strong>
      <xsl:value-of select="ll:getLL('email')"/>
      <xsl:text>: </xsl:text>
    </strong>
    <span class="email">
      <xsl:value-of select="." disable-output-escaping="yes"/>
    </span>
    <br />
  </xsl:template>

  <xsl:template match="//core:result/core:content/person:organisationAssociations/person:organisationAssociation/person:address/extensions:room">
    <strong>
      <xsl:value-of select="ll:getLL('office')"/>
      <xsl:text>: </xsl:text>
    </strong>
    <xsl:element name="a">
      <xsl:attribute name="href">
        <xsl:value-of select="ll:getLL('building_url')"/>
        <xsl:value-of select="str:tokenize(., '-')[1]"/>
        <xsl:text>.htm</xsl:text>
      </xsl:attribute>
      <xsl:value-of select="ll:getLL('buildingShort')"/>
      <xsl:text>-</xsl:text>
      <xsl:value-of select="str:tokenize(., '-')[1]"/>
    </xsl:element>

    <xsl:if test="str:tokenize(., '-')[2]">
      <xsl:text> </xsl:text>
      <xsl:value-of select="str:tokenize(., '-')[2]"/>
    </xsl:if>
    <br />
  </xsl:template>


</xsl:stylesheet>