<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns="http://www.w3.org/1999/xhtml"
                xmlns:fn="http://www.w3.org/2005/02/xpath-functions"
                xmlns:regexp="http://exslt.org/regular-expressions"
                xmlns:ll="http://typo3.org/extensions/repository/view/pure/current/"
                                
                xmlns:core="http://atira.dk/schemas/pure4/model/core/stable"
                xmlns:publication="http://atira.dk/schemas/pure4/model/abstractpublication/stable"
                xmlns:person="http://atira.dk/schemas/pure4/model/abstractperson/stable"
                xmlns:extensions="http://atira.dk/schemas/pure4/model/extensions/stable"
                xmlns:organisation="http://atira.dk/schemas/pure4/model/abstractorganisation/stable"
                xmlns:event="http://atira.dk/schemas/pure4/model/abstractevent/stable"
                xmlns:stab="http://atira.dk/schemas/pure4/dk/model/publication/stable"
                
                xmlns:str="http://exslt.org/strings"
                exclude-result-prefixes="fn str regexp ll core publication person extensions organisation event stab">
  <xsl:import href="localization.xsl" />
  <xsl:param name="ll:localizationFile" select="'locallang_person.xml'" />
  
  <xsl:param name="hideJobtitleInList" />
  
  <xsl:output omit-xml-declaration="yes" encoding="utf-8"/>

  <xsl:template match="/">
    <div>
      <table class="pure-persons-table">
        <thead>
          <tr>
            <th>
              <xsl:value-of select="ll:getLL('name')"/>
            </th>
            <xsl:if test="not($hideJobtitleInList)">
                <th>
                  <xsl:value-of select="ll:getLL('jobtitle')"/>
                </th>
            </xsl:if>
            <th>
              <xsl:value-of select="ll:getLL('email')"/>
            </th>
            <th>
              <xsl:value-of select="ll:getLL('phoneHeader')"/>
            </th>
            <th>
              <xsl:value-of select="ll:getLL('building')"/>
            </th>
            <th>
              <xsl:value-of select="ll:getLL('room')"/>
            </th>
          </tr>
        </thead>
        <tbody>
          <xsl:for-each select="//core:result/core:content">
            <tr>
              <td>
                <a href="{typo3/links/personUrl}">
                  <xsl:value-of select="person:name/core:lastName"/>
                  <xsl:text>, </xsl:text>
                  <xsl:value-of select="person:name/core:firstName" />
                </a>
              </td>
              <xsl:variable name="primaryOrganisation" select="person:organisationAssociations/person:organisationAssociation[not(person:period/extensions:endDate)][1]" />
              <xsl:if test="not($hideJobtitleInList)">
                  <td>
                    <xsl:apply-templates select="$primaryOrganisation/person:jobTitle/core:term" mode="localize" />
                  </td>
              </xsl:if>
              <td>
                <xsl:value-of disable-output-escaping="yes" select="$primaryOrganisation/emailLink"/>
              </td>
              <td>
                <xsl:choose>
                  <xsl:when test="string-length($primaryOrganisation/person:phone)=8">
                    <xsl:value-of select="ll:getLL('phoneprefix.DK')"/>
                    <xsl:value-of select="substring($primaryOrganisation/person:phone,1,4)"/>
                    <xsl:text> </xsl:text>
                    <xsl:value-of select="substring($primaryOrganisation/person:phone,5,4)"/>
                  </xsl:when>
                  <xsl:otherwise>
                    <xsl:value-of select="$primaryOrganisation/person:phone"/>
                  </xsl:otherwise>
                </xsl:choose>
              </td>
              <td>
                <xsl:element name="a">
                  <xsl:attribute name="href">
                    <xsl:value-of select="ll:getLL('building_url')"/>
                    <xsl:value-of select="str:tokenize($primaryOrganisation/person:address/extensions:room, '-')[1]"/>
                    <xsl:text>.htm</xsl:text>
                  </xsl:attribute>
                  <xsl:value-of select="str:tokenize($primaryOrganisation/person:address/extensions:room, '-')[1]"/>
                </xsl:element>
              </td>
              <td>
                <xsl:value-of select="str:tokenize($primaryOrganisation/person:address/extensions:room, '-')[2]"/>
              </td>
            </tr>
          </xsl:for-each>
        </tbody>
      </table>
    </div>
  </xsl:template>

</xsl:stylesheet>