<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns="http://www.w3.org/1999/xhtml"
                xmlns:fn="http://www.w3.org/2005/02/xpath-functions"
                xmlns:regexp="http://exslt.org/regular-expressions"
                xmlns:ll="http://typo3.org/extensions/repository/view/pure/current/"
                xmlns:php="http://php.net/xsl"
                
                xmlns:core="http://atira.dk/schemas/pure4/model/core/stable"
                xmlns:publication="http://atira.dk/schemas/pure4/model/abstractpublication/stable"
                xmlns:person="http://atira.dk/schemas/pure4/model/abstractperson/stable"
                xmlns:extensions="http://atira.dk/schemas/pure4/model/extensions/stable"
                xmlns:organisation="http://atira.dk/schemas/pure4/model/abstractorganisation/stable"
                xmlns:event="http://atira.dk/schemas/pure4/model/abstractevent/stable"
                xmlns:publisher="http://atira.dk/schemas/pure4/model/abstractpublisher/stable"
                xmlns:stab="http://atira.dk/schemas/pure4/dk/model/publication/stable"
                
                xmlns:str="http://exslt.org/strings" 
                exclude-result-prefixes="fn str regexp php ll core publication person extensions organisation event publisher stab">
  <xsl:import href="localization.xsl" />
  <xsl:param name="ll:localizationFile" select="'locallang_publication.xml'" />
  
  <xsl:output encoding="utf-8" />
  <xsl:param name="pubsort" />
  <xsl:param name="pureUrl" select="'http://pure3a.au.dk:8080/ws/axis2/services/PureWebService/'" />
  <xsl:param name="browse_links" />


  <xsl:template match="core:result/core:content">
      <!--Authors-->
      <xsl:apply-templates select="publication:persons"/>

      <xsl:apply-templates select="publication:publicationDate"/>

      <xsl:text>, </xsl:text>
      <xsl:element name="a">
        <xsl:attribute name="href">
          <xsl:value-of select="typo3/links/publicationUrl"/>
        </xsl:attribute>
        <xsl:text>"</xsl:text>
        <xsl:value-of select="publication:title" disable-output-escaping="yes"/>
        <xsl:text>"</xsl:text>
      </xsl:element>

      <xsl:apply-templates select="publication:hostEditors[publication:hostEditor[node()]]"/>
      <xsl:apply-templates select="publication:hostPublicationTitle"/>
      <xsl:apply-templates select="publication:volume"/>
      <xsl:apply-templates select="publication:associatedPublishers/publisher:publisher/publisher:name"/>
    
      <!--<xsl:apply-templates select="proceedingTitle"/> --><!--TODO:-->
    
      <xsl:apply-templates select="publication:associatedPublishers/publisher:placeOfPublication"/>
    
      <!--<xsl:apply-templates select="publication:journal"/> --><!--TODO:-->
    
      <xsl:apply-templates select="publication:journalNumber"/>
      <xsl:apply-templates select="publication:pages"/>
      <xsl:text>.</xsl:text>
      <xsl:apply-templates select="publisher:external"/>
      <xsl:apply-templates select="publication:typeClassification"/>

    <!-- TODO: Where is state now?-->
      <!--<xsl:apply-templates select="state"/>-->

  </xsl:template>

  <!--Authors-->
  <xsl:template match="publication:persons">
    <xsl:for-each select="person:personAssociation"> <!--[contains(./person:personRole/core:uri/text(), 'author')]-->
      <xsl:value-of select="person:name/core:lastName"/>
      <xsl:text>, </xsl:text>
      <xsl:for-each select="str:tokenize(person:name/core:firstName, ' ')">
        <xsl:value-of select="substring(.,1,1)" />
        <xsl:text>.</xsl:text>
        <xsl:if test="position()!=last()">
          <xsl:text> </xsl:text>
        </xsl:if>
      </xsl:for-each>
      <xsl:if test="position()!=last()">
        <xsl:text>, </xsl:text>
      </xsl:if>
    </xsl:for-each>
  </xsl:template>

  <xsl:template match="publication:publicationDate">
    <xsl:text>, </xsl:text>
    <xsl:if test="core:day">
      <xsl:value-of select="core:day"/>
      <xsl:text>.</xsl:text>
    </xsl:if>
    <xsl:if test="core:month">
      <xsl:value-of select="core:month"/>
      <xsl:text>.</xsl:text>
    </xsl:if>
    <xsl:if test="core:year">
      <xsl:value-of select="core:year"/>
    </xsl:if>
  </xsl:template>


  <xsl:template match="publication:hostEditors">
    <xsl:text>, </xsl:text>
    <xsl:for-each select="publication:hostEditor[node()]">
      <xsl:value-of select="core:lastName"/>
      <xsl:text>, </xsl:text>
      <xsl:for-each select="str:tokenize(core:firstName, ' ')">
        <xsl:value-of select="substring(.,1,1)" />
        <xsl:text>.</xsl:text>
        <xsl:if test="position()!=last()">
          <xsl:text> </xsl:text>
        </xsl:if>
      </xsl:for-each>
      <xsl:if test="position()!=last()">
        <xsl:text>, </xsl:text>
      </xsl:if>
    </xsl:for-each>
    <xsl:text> (</xsl:text>
    <xsl:value-of select="ll:getLL('editorsShort')"/>
    <xsl:text>)</xsl:text>
  </xsl:template>


  <xsl:template match="publication:hostPublicationTitle">
    <xsl:text>, </xsl:text>
    <i>
      <xsl:value-of select="."/>
    </i>
  </xsl:template>

  <xsl:template match="publication:volume">
    <xsl:text>, vol. </xsl:text>
    <xsl:value-of select="."/>
  </xsl:template>

  <xsl:template match="publication:associatedPublishers/publisher:publisher/publisher:name">
    <xsl:text>, </xsl:text>
    <xsl:value-of select="."/>
  </xsl:template>

  <xsl:template match="proceedingTitle">
    <xsl:text>, </xsl:text>
    <i>
      <xsl:value-of select="."/>
    </i>
  </xsl:template>

  <xsl:template match="publication:associatedPublishers/publisher:placeOfPublication">
    <xsl:text>, </xsl:text>
    <xsl:value-of select="."/>
  </xsl:template>

  <xsl:template match="journal">
    <xsl:text>, </xsl:text>
    <i>
      <xsl:value-of select="ll:localize(title_pri, title_sec)"/>
    </i>
  </xsl:template>

  <xsl:template match="publication:journalNumber">
    <xsl:text>, nr. </xsl:text>
    <xsl:value-of select="."/>
  </xsl:template>

  <xsl:template match="publication:pages">
    <xsl:text>, s. </xsl:text>
    <xsl:value-of select="."/>
  </xsl:template>

  <xsl:template match="publisher:external">
    <xsl:if test="extensions:external = 'true'">
      <xsl:text> * )</xsl:text>
    </xsl:if>
  </xsl:template>

  <xsl:template match="publication:typeClassification">
    <xsl:text>&#160;</xsl:text>
    <span class="pubtype">
      <xsl:apply-templates select="core:term" mode="localize"/>
      <!--<xsl:value-of select="ll:getLL(concat('type.', .), .)"/>-->
    </span>
  </xsl:template>


  <xsl:template match="state">
    <xsl:if test=". != 'Published'">
      <span class="pubstatus">
        <xsl:value-of select="ll:getLL(concat('state.', .), .)"/>
      </span>
    </xsl:if>
  </xsl:template>


</xsl:stylesheet>