<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                
                xmlns:dc="http://purl.org/dc/elements/1.1/" 
                xmlns:atom="http://www.w3.org/2005/Atom"
                xmlns:fn="http://www.w3.org/2005/02/xpath-functions"
                xmlns:regexp="http://exslt.org/regular-expressions"
                xmlns:date="http://exslt.org/dates-and-times"
                xmlns:ll="http://typo3.org/extensions/repository/view/pure/current/"
                xmlns:str="http://exslt.org/strings" 
                
                xmlns:core="http://atira.dk/schemas/pure4/model/core/stable"
                xmlns:publication="http://atira.dk/schemas/pure4/model/abstractpublication/stable"
                xmlns:person="http://atira.dk/schemas/pure4/model/abstractperson/stable"
                xmlns:extensions="http://atira.dk/schemas/pure4/model/extensions/stable"
                xmlns:organisation="http://atira.dk/schemas/pure4/model/abstractorganisation/stable"
                xmlns:event="http://atira.dk/schemas/pure4/model/abstractevent/stable"
                xmlns:publisher="http://atira.dk/schemas/pure4/model/abstractpublisher/stable"
                xmlns:stab="http://atira.dk/schemas/pure4/dk/model/publication/stable"
                
                exclude-result-prefixes="fn str regexp date ll core publication person extensions organisation event publisher stab">

  <xsl:import href="localization.xsl" />
  <xsl:param name="ll:localizationFile" select="'locallang_publication.xml'" />
  
  <xsl:param name="rssTitle" select="'RSS'" />
  <xsl:output encoding="utf-8" indent="yes" method="xml"/>
  
  <!-- See http://cyber.law.harvard.edu/rss/rss.html for RSS specs.-->
  
  <xsl:template match="/">
    <rss version="2.0" xmlns:dc="http://purl.org/dc/elements/1.1/" xmlns:atom="http://www.w3.org/2005/Atom">
      <channel>
        <title>
          <xsl:text>Publications - </xsl:text>
          <xsl:value-of select="$rssTitle"/>
        </title>
        <link>
          <xsl:value-of select="typo3/links/rssSoruceUrl" />
        </link>
        <atom:link rel="self" href="{typo3/links/rssAbsoluteUrl}" type="application/rss+xml" />
        <description/>
        <language>en-us</language>
        <generator>PURE Extension</generator>
        <webMaster>typo3support@science.au.dk (Web Department)</webMaster>
        <ttl>30</ttl>
      <xsl:apply-templates select="//core:result/core:content" />
      </channel>
    </rss>
  </xsl:template>

  <xsl:template match="//core:result/core:content">
    <item>
      <title>
        <xsl:value-of select="publication:title" disable-output-escaping="yes"/>
      </title>
      <link>
        <xsl:value-of select="typo3/links/publicationAbsoluteUrl"/>
      </link>
      <dc:creator>
        <xsl:apply-templates select="publication:persons" />
      </dc:creator>
      <xsl:if test="publication:associatedPublishers/publisher:publisher/publisher:name">
        <dc:publisher>
          <xsl:value-of select="publication:associatedPublishers/publisher:publisher/publisher:name"/>
        </dc:publisher>
      </xsl:if>
      <description>
        <xsl:apply-templates select="publication:abstract" mode="localize" />
      </description>
      <xsl:if test="publicationCategory">
        <category>
          <xsl:value-of select="publicationCategory"/>
        </category>
      </xsl:if>
      <pubDate>
        <!--Use created to get publicationDate-->
        <xsl:apply-templates select="core:created" />
      </pubDate>
      <guid isPermaLink="false">
        <xsl:value-of select="@uuid" />
      </guid>
    </item>
  </xsl:template>

  <xsl:template match="publication:persons">
    <xsl:for-each select="person:personAssociation[contains(./person:personRole/core:uri/text(), 'author')]">
      <xsl:value-of select="person:name/core:lastName"/>
      <xsl:text>, </xsl:text>
      <xsl:for-each select="str:tokenize(person:name/core:firstName, ' ')">
        <xsl:value-of select="substring(.,1,1)" />
        <xsl:text>.</xsl:text>
        <xsl:if test="position()!=last()">
          <xsl:text> </xsl:text>
        </xsl:if>
      </xsl:for-each>
      <xsl:if test="position()!=last()">
        <xsl:text>, </xsl:text>
      </xsl:if>
    </xsl:for-each>
  </xsl:template>


  <xsl:template match="core:created">
    <!--Format: Sat, 07 Sep 2002 09:42:31 GMT-->
    <xsl:value-of select="date:day-abbreviation(.)"/>
    <xsl:text>, </xsl:text>
    <xsl:choose>
      <xsl:when test="date:day-in-month(.) &lt; 10">
        <xsl:text>0</xsl:text>
        <xsl:value-of select="date:day-in-month(.)"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="date:day-in-month(.)"/>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:text> </xsl:text>
    <xsl:value-of select="date:month-abbreviation(.)"/>
    <xsl:text> </xsl:text>
    <xsl:value-of select="date:year(.)"/>
    <xsl:text> </xsl:text>
    <xsl:if test="10 &gt; date:hour-in-day(.)">
      <xsl:text>0</xsl:text>  
    </xsl:if>
    <xsl:value-of select="date:hour-in-day(.)"/>
    <xsl:text>:</xsl:text>
    <xsl:if test="10 &gt; date:minute-in-hour(.)">
      <xsl:text>0</xsl:text>
    </xsl:if>
    <xsl:value-of select="date:minute-in-hour(.)"/>
    <xsl:text>:</xsl:text>
    <xsl:if test="10 &gt; date:second-in-minute(.)">
      <xsl:text>0</xsl:text>
    </xsl:if>
    <xsl:value-of select="date:second-in-minute(.)"/>
    <xsl:text> GMT</xsl:text>
  </xsl:template>
  
</xsl:stylesheet>