<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns="http://www.w3.org/1999/xhtml"
                xmlns:fn="http://www.w3.org/2005/02/xpath-functions"
                xmlns:regexp="http://exslt.org/regular-expressions"
                xmlns:ll="http://typo3.org/extensions/repository/view/pure/current/"
                xmlns:php="http://php.net/xsl"
                xmlns:str="http://exslt.org/strings"
                
                xmlns:core="http://atira.dk/schemas/pure4/model/core/stable" 
                xmlns:publication="http://atira.dk/schemas/pure4/model/abstractpublication/stable"
                xmlns:person="http://atira.dk/schemas/pure4/model/abstractperson/stable"
                xmlns:extensions="http://atira.dk/schemas/pure4/model/extensions/stable"
                xmlns:organisation="http://atira.dk/schemas/pure4/model/abstractorganisation/stable"
                xmlns:event="http://atira.dk/schemas/pure4/model/abstractevent/stable"
                xmlns:stab="http://atira.dk/schemas/pure4/dk/model/publication/stable"
  
                exclude-result-prefixes="fn str regexp php ll core publication person extensions organisation event stab">
  <xsl:import href="localization.xsl" />
  <xsl:param name="ll:localizationFile" select="'locallang_publication.xml'" />

  <xsl:output encoding="utf-8" />
  <xsl:param name="pubsort" />
  <xsl:param name="pureUrl" select="'http://pure3a.au.dk:8080/ws/axis2/services/PureWebService/'" />
  <xsl:param name="browse_links" />

  <xsl:param name="hide_rss" />


  <!-- Include grouping XSLT -->
  <xsl:include href="Group.xsl" />
  <xsl:include href="TEMPLATE_PUBLICATIONS_FORMAT_STANDARD.xsl" />

  <xsl:template match="/">
    <div class="publication-simple">
      <div class="sorting pure-ajax-request">
        <p>
          <xsl:value-of select="ll:getLL('sortby')"/>
          <xsl:text>: </xsl:text>
          <xsl:choose>
            <xsl:when test="$pubsort = 'publicationYear'">
              <strong>
                <xsl:value-of select="ll:getLL('sortDate')"/>
              </strong>
            </xsl:when>
            <xsl:otherwise>
              <a href="{typo3/links/sortDateUrl}">
                <xsl:value-of select="ll:getLL('sortDate')"/>
              </a>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:text> | </xsl:text>
          <xsl:choose>
            <xsl:when test="$pubsort = 'authorLastName'">
              <strong>
                <xsl:value-of select="ll:getLL('sortAuthor')"/>
              </strong>
            </xsl:when>
            <xsl:otherwise>
              <a href="{typo3/links/sortAuthorUrl}">
                <xsl:value-of select="ll:getLL('sortAuthor')"/>
              </a>
            </xsl:otherwise>
          </xsl:choose>
          <xsl:text> | </xsl:text>
          <xsl:choose>
            <xsl:when test="$pubsort = 'title'">
              <strong>
                <xsl:value-of select="ll:getLL('sortTitle')"/>
              </strong>
            </xsl:when>
            <xsl:otherwise>
              <a href="{typo3/links/sortTitleUrl}">
                <xsl:value-of select="ll:getLL('sortTitle')"/>
              </a>
            </xsl:otherwise>
          </xsl:choose>

          <xsl:if test="//request/personnelIds">
            <xsl:variable name="haveSelcted" select="php:function('tx_pure_xsltfunctions::haveSelectedByPersons', $pureUrl, 'getPublications', string(//request/personnelIds))" />
            <xsl:if test="$haveSelcted">
              <br />
              <xsl:value-of select="ll:getLL('showSelected')"/>
              <xsl:text> </xsl:text>
              <xsl:choose>
                <xsl:when test="//request/selectedByPersons = 'true'">
                  <a href="{typo3/links/allPublicationsUrl}">
                    <xsl:value-of select="ll:getLL('allSelected')"/>
                  </a>
                </xsl:when>
                <xsl:otherwise>
                  <strong>
                    <xsl:value-of select="ll:getLL('allSelected')"/>
                  </strong>
                </xsl:otherwise>
              </xsl:choose>
              <xsl:text> | </xsl:text>
              <xsl:choose>
                <xsl:when test="//request/selectedByPersons = 'true'">
                  <strong>
                    <xsl:value-of select="ll:getLL('selectedByPerson')"/>
                  </strong>
                </xsl:when>
                <xsl:otherwise>
                  <a href="{typo3/links/selectedPublicationsUrl}">
                    <xsl:value-of select="ll:getLL('selectedByPerson')"/>
                  </a>
                </xsl:otherwise>
              </xsl:choose>
              <xsl:value-of select="request/personnelIds"/>
            </xsl:if>
          </xsl:if>
        </p>
      </div>
      <xsl:if test="$hide_rss != 'true'">
        <a href="{typo3/links/rssUrl}" title="RSS" class="feedlink">
          <xsl:text>&#160;</xsl:text>
        </a>
      </xsl:if>

      <div class="publications">
        <!--TODO: Redo-->
        <!--<ul class="au-smallsans">
          <xsl:for-each select="//core:result/core:content[@uuid]">
            <li>
              <xsl:apply-templates select="." />
            </li>
          </xsl:for-each>
        </ul>-->
        <xsl:apply-templates select="." mode="group" />

        <xsl:if test="//core:result/core:content/publication:external[extensions:external = 'true']">
          <p>
            <xsl:text>* ) </xsl:text>
            <xsl:value-of select="ll:getLL('producedExternal')"/>
          </p>
        </xsl:if>
      </div>

      <xsl:if test="$browse_links">
        <div class="browse-links pure-ajax-request">
          <p class="results_numbers">
            <xsl:value-of select="$browse_links" disable-output-escaping="yes"/>
          </p>
        </div>
      </xsl:if>

    </div>
  </xsl:template>


  <xsl:template name="list">
    <xsl:param name="items" />
    <ul class="au-smallsans">
      <xsl:for-each select="$items">
        <li>
          <xsl:apply-templates select="." />
        </li>
      </xsl:for-each>
    </ul>
  </xsl:template>

</xsl:stylesheet>