<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns="http://www.w3.org/1999/xhtml"
                xmlns:fn="http://www.w3.org/2005/02/xpath-functions"
                xmlns:regexp="http://exslt.org/regular-expressions"
                xmlns:ll="http://typo3.org/extensions/repository/view/pure/current/"
                xmlns:date="http://exslt.org/dates-and-times"
                xmlns:organisation="http://atira.dk/schemas/pure4/model/abstractorganisation/stable"
                xmlns:str="http://exslt.org/strings" exclude-result-prefixes="fn str regexp ll date organisation">
  <xsl:import href="localization.xsl" />
  <xsl:param name="ll:localizationFile" select="'locallang_search.xml'" />
  <xsl:output encoding="utf-8"/>
  <xsl:template match="/">
    <div class="pure_search_activities">
      <form class="pure_search_form" method="get" action="{typo3search/config/formUrl}">
        <div>
          <input name="tx_pure_pi[search_type]" type="hidden" value="activities"/>
          <input name="tx_pure_pi[organisationIdsToChoose]" type="hidden" value="{typo3search/config/organisationIdsToChoose}"/>
          <input name="tx_pure_pi[organisationIds]" type="hidden" value="{typo3search/config/organisationIdsToChoose}"/>
        </div>
        <div class="pure-search">
          <input type="text" name="tx_pure_pi[sword]" value="{typo3search/config/sword}" />
          <input type="submit" name="search" value="{ll:getLL('search_button')}" />
        </div>
        <div class="pure-search-settings">
          <table border="0" cellspacing="0" cellpadding="2">
            <tbody>
              <xsl:if test="count(typo3search/config/organisations/item) > 0">
              <tr>
                <td>
                  <xsl:value-of select="ll:getLL('search_organisations')"/>
                </td>
                <td>
                  <select name="tx_pure_pi[organisationIds]" size="1">
                    <xsl:if test="count(typo3search/config/organisations/item) > 1">
                      <xsl:element name="option">
                        <xsl:attribute name="value">
                          <xsl:value-of select="/typo3search/config/organisationIdsToChoose"/>
                        </xsl:attribute>
                        <xsl:if test="string(/typo3search/config/organisationIdsToChoose) = string(/typo3search/config/selectedOrganisationIds)">
                          <xsl:attribute name="selected">
                            <xsl:text>selected</xsl:text>
                          </xsl:attribute>
                        </xsl:if>
                        <xsl:value-of select="ll:getLL('search_organisations_all')"/>
                      </xsl:element>
                    </xsl:if>
                    <xsl:for-each select="typo3search/config/organisations/item">
                      <xsl:element name="option">
                        <xsl:attribute name="value">
                          <xsl:value-of select="id"/>
                        </xsl:attribute>
                        <xsl:if test="id = /typo3search/config/selectedOrganisationIds">
                          <xsl:attribute name="selected">
                            <xsl:text>selected</xsl:text>
                          </xsl:attribute>
                        </xsl:if>
                        <xsl:apply-templates select="organisation:name" mode="localize"  />
                      </xsl:element>
                    </xsl:for-each>
                  </select>
                </td>
              </tr>
              </xsl:if>
              <tr>
                <td>
                  <xsl:value-of select="ll:getLL('search_publication_year_between')"/>
                </td>
                <td>

                  <select name="tx_pure_pi[startYear]" size="1">

                    <xsl:call-template name="for.loop.yearOptions">
                      <xsl:with-param name="start">
                        <xsl:value-of select="date:year(date:date-time())"/>
                      </xsl:with-param>
                      <xsl:with-param name="end">
                        <xsl:value-of select="1982"/>
                      </xsl:with-param>
                      <xsl:with-param name="inc">
                        <xsl:value-of select="-1"/>
                      </xsl:with-param>
                      <xsl:with-param name="selected">
                        <xsl:choose>
                          <xsl:when test="typo3search/config/selectedStartYear != 0">
                            <xsl:value-of select="typo3search/config/selectedStartYear"/>
                          </xsl:when>
                          <xsl:otherwise>
                            <xsl:value-of select="'1982'"/>
                          </xsl:otherwise>
                        </xsl:choose>
                      </xsl:with-param>
                    </xsl:call-template>
                  </select>
                  <xsl:text> </xsl:text>
                  <xsl:value-of select="ll:getLL('search_and_word')"/>
                  <xsl:text> </xsl:text>
                  <select name="tx_pure_pi[endYear]" size="1">
                    <xsl:call-template name="for.loop.yearOptions">
                      <xsl:with-param name="start">
                        <xsl:value-of select="date:year(date:date-time()) + 1"/>
                      </xsl:with-param>
                      <xsl:with-param name="end">
                        <xsl:value-of select="1982"/>
                      </xsl:with-param>
                      <xsl:with-param name="inc">
                        <xsl:value-of select="-1"/>
                      </xsl:with-param>
                      <xsl:with-param name="selected">
                        <xsl:value-of select="typo3search/config/selectedEndYear"/>
                      </xsl:with-param>
                    </xsl:call-template>
                  </select>
                </td>
              </tr>
            </tbody>
          </table>
        </div>
        <p class="pure-show-search-settings" style="display: none;">
          <a href="#">
            <xsl:value-of select="ll:getLL('show_advanced_search_options')"/>
          </a>
        </p>
        <p class="pure-hide-search-settings" style="display: none;">
          <a href="#">
            <xsl:value-of select="ll:getLL('hide_advanced_search_options')"/>
          </a>
        </p>       
      </form>
      <xsl:if test="typo3search/config/resultCount > 0">
        <h3>
          <xsl:value-of select="ll:getLL('search_found_found')"/>
          <xsl:text> </xsl:text>
          <xsl:value-of select="typo3search/config/resultCount"/>
          <xsl:text> </xsl:text>
          <xsl:choose>
            <xsl:when test="number(typo3search/config/resultCount) = 1">
              <xsl:value-of select="ll:getLL('search_found_results_one')"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="ll:getLL('search_found_results')"/>
            </xsl:otherwise>
          </xsl:choose>
        </h3>
      </xsl:if>
      <div>
        <xsl:value-of disable-output-escaping="yes" select="typo3search/result" />
      </div>
    </div>
  </xsl:template>



  <xsl:template name="for.loop.yearOptions">
    <xsl:param name="start" />
    <xsl:param name="end" />
    <xsl:param name="inc" />
    <xsl:param name="selected" />

    <xsl:if test="$start &gt;= $end">
      <xsl:element name="option">
        <xsl:attribute name="value">
          <xsl:value-of select="$start"/>
        </xsl:attribute>
        <xsl:if test="$selected = $start">
          <xsl:attribute name="selected">
            <xsl:text>selected</xsl:text>
          </xsl:attribute>
        </xsl:if>
          <xsl:value-of select="$start"/>
      </xsl:element>
    </xsl:if>

    <xsl:if test="$start &gt;= $end">
      <xsl:call-template name="for.loop.yearOptions">
        <xsl:with-param name="start">
          <xsl:value-of select="$start + $inc"/>
        </xsl:with-param>
        <xsl:with-param name="end">
          <xsl:value-of select="$end"/>
        </xsl:with-param>
        <xsl:with-param name="inc">
          <xsl:value-of select="$inc"/>
        </xsl:with-param>
        <xsl:with-param name="selected">
          <xsl:value-of select="$selected"/>
        </xsl:with-param>
      </xsl:call-template>
    </xsl:if>
  </xsl:template>

  <xsl:template name="categories">
    <xsl:param name="value" />
    <xsl:param name="name" />
    <xsl:param name="selected" />
    <xsl:element name="option">
      <xsl:attribute name="value">
        <xsl:value-of select="$value"/>
      </xsl:attribute>
      <xsl:if test="$selected = $value">
        <xsl:attribute name="selected">
          <xsl:text>selected</xsl:text>
        </xsl:attribute>
      </xsl:if>
        <xsl:value-of select="$name"/>
    </xsl:element>

  </xsl:template>

</xsl:stylesheet>