<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns="http://www.w3.org/1999/xhtml"
                xmlns:fn="http://www.w3.org/2005/02/xpath-functions"
                xmlns:regexp="http://exslt.org/regular-expressions"
                xmlns:date="http://exslt.org/dates-and-times"
                xmlns:ll="http://typo3.org/extensions/repository/view/pure/current/"
                xmlns:str="http://exslt.org/strings" 
                xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
                xmlns:types="http://www.atira.dk/schemas/pure/services/types"
               
                xsi:type="xsl:transform"
                xmlns:php="http://php.net/xsl"
                
                xmlns:core="http://atira.dk/schemas/pure4/model/core/stable"
                xmlns:publication="http://atira.dk/schemas/pure4/model/abstractpublication/stable"
                xmlns:person="http://atira.dk/schemas/pure4/model/abstractperson/stable"
                xmlns:extensions="http://atira.dk/schemas/pure4/model/extensions/stable"
                xmlns:organisation="http://atira.dk/schemas/pure4/model/abstractorganisation/stable"
                xmlns:event="http://atira.dk/schemas/pure4/model/abstractevent/stable"
                xmlns:publisher="http://atira.dk/schemas/pure4/model/abstractpublisher/stable"
                xmlns:stab="http://atira.dk/schemas/pure4/dk/model/publication/stable"
                xmlns:journal="http://atira.dk/schemas/pure4/model/abstractjournal/stable"
                xmlns:activity="http://atira.dk/schemas/pure4/model/abstractactivity/stable"
                
                exclude-result-prefixes="fn str regexp date xsi php types ll core publication person extensions organisation event publisher stab journal activity"
                >
  <xsl:import href="localization.xsl" />
  <xsl:param name="ll:localizationFile" select="'locallang_activity.xml'" />
  <xsl:output encoding="utf-8"/>

  <xsl:template match="/">
   <div class="pure-single-activity" >
      <xsl:for-each select="//core:result/core:content">
        <h1 style="text-transform: none;">
          <xsl:value-of select="ll:getLL(concat('type.', activityType), activityType)"/>
          <xsl:if test="variant">
            <xsl:text> · </xsl:text>
            <xsl:value-of select="ll:getLL(concat('variant.', variant), variant)"/>
          </xsl:if>
        </h1>

        <table class="nyt" style="margin-top: 15px;" cellspacing="0" cellpadding="0" border="0">
          
          <xsl:apply-templates select="activity:title"/>
          <xsl:apply-templates select="activity:abstract"/>
        
                    
          <xsl:apply-templates select="." />

        </table>
      </xsl:for-each>
    </div>
  </xsl:template>
  
  <xsl:template match="core:content[contains(core:type, 'Participation')]">
    <xsl:apply-templates select="activity:bodyAffiliation" />
    <xsl:apply-templates select="activity:bodyName" />
    <xsl:apply-templates select="activity:bodyType" />
  </xsl:template>
  
  <xsl:template match="core:content[contains(core:type, 'Lecture')]">
    <xsl:apply-templates select="activity:arrangement"/>
    <xsl:apply-templates select="activity:arranger"/>
    <xsl:apply-templates select="activity:countryForLecture"/>
    <xsl:apply-templates select="activity:doi"/>
    <xsl:apply-templates select="activity:place"/>
    <xsl:apply-templates select="activity:subTitle"/>
  </xsl:template>
      
  <xsl:template match="core:content[contains(core:type, 'Appearance')]">
    <xsl:apply-templates select="activity:mediumName"/>
    <xsl:apply-templates select="activity:producerName"/>
    <xsl:apply-templates select="activity:subject"/>
    <xsl:apply-templates select="activity:subTitle"/>
  </xsl:template>
      
  <xsl:template match="core:content[contains(core:type, 'ConferenceParticipation')]">
    <xsl:apply-templates select="activity:city"/>
    <xsl:apply-templates select="activity:conferenceNumber"/>
    <xsl:apply-templates select="activity:country"/>
  </xsl:template>
    
  <xsl:template match="core:content[contains(core:type, 'Ongoing')]">
    <xsl:apply-templates select="activity:institutionName"/>
    <xsl:apply-templates select="activity:issnIsbnSerials"/>
    <xsl:apply-templates select="activity:publicationPlace"/>
  </xsl:template>

  <xsl:template match="core:content[contains(core:type, 'Other')]">
    <xsl:apply-templates select="activity:city"/>
    <xsl:apply-templates select="activity:institutionName"/>
    <xsl:apply-templates select="activity:specificCountry"/>
    <xsl:apply-templates select="activity:subTitle"/>
  </xsl:template>
  
  
   <!--
   //////////////////////////////////////////////////////
   /////////////Participation Fields START //////////////
   //////////////////////////////////////////////////////
   -->

  <xsl:template match="//core:result/core:content/activity:bodyAffiliation">
    <xsl:call-template name="table-item">
      <xsl:with-param name="value">
        <xsl:apply-templates select="." mode="localize" />
      </xsl:with-param>
      <xsl:with-param name="title">
        <xsl:value-of select="ll:getLL('bodyAffiliation')"/>
      </xsl:with-param>
    </xsl:call-template>
  </xsl:template>
  
  <xsl:template match="//core:result/core:content/activity:bodyName">
    <xsl:call-template name="table-item">
      <xsl:with-param name="value">
        <xsl:apply-templates select="." mode="localize" />
      </xsl:with-param>
      <xsl:with-param name="title">
        <xsl:value-of select="ll:getLL('bodyName')"/>
      </xsl:with-param>
    </xsl:call-template>
  </xsl:template>
      
  <xsl:template match="//core:result/core:content/activity:bodyType">
    <xsl:call-template name="table-item">
      <xsl:with-param name="value">
        <xsl:apply-templates select="." mode="localize" />
      </xsl:with-param>
      <xsl:with-param name="title">
        <xsl:value-of select="ll:getLL('bodyType')"/>
      </xsl:with-param>
    </xsl:call-template>
  </xsl:template>

    
  
  <!-- 
   //////////////////////////////////////////////////////
   /////////////Participation Fields End //////////////// 
   //////////////////////////////////////////////////////  -->


  <!--    
   //////////////////////////////////////////////////////
   /////////////Lecture Fields Start ////////////////////
   //////////////////////////////////////////////////////   
   -->

  <xsl:template match="//core:result/core:content/activity:arrangement">
    <xsl:call-template name="table-item">
      <xsl:with-param name="value">
        <xsl:value-of select="."/>
      </xsl:with-param>
      <xsl:with-param name="title">
        <xsl:value-of select="ll:getLL('arrangement')"/>
      </xsl:with-param>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="//core:result/core:content/activity:arranger">
    <xsl:call-template name="table-item">
      <xsl:with-param name="value">
        <xsl:value-of select="."/>
      </xsl:with-param>
      <xsl:with-param name="title">
        <xsl:value-of select="ll:getLL('arranger')"/>
      </xsl:with-param>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="//core:result/core:content/activity:countryForLecture">
    <xsl:call-template name="table-item">
      <xsl:with-param name="value">
        <xsl:apply-templates select="core:term" mode="localize" />
      </xsl:with-param>
      <xsl:with-param name="title">
        <xsl:value-of select="ll:getLL('countryForLecture')"/>
      </xsl:with-param>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="//core:result/core:content/activity:doi">
    <xsl:call-template name="table-item">
      <xsl:with-param name="value">
        <a href="{concat('http://dx.doi.org/', .)}">
          <xsl:value-of select="."/>
        </a>
      </xsl:with-param>
      <xsl:with-param name="title">
        <xsl:value-of select="ll:getLL('doi')"/>
      </xsl:with-param>
    </xsl:call-template>
  </xsl:template>
  
  <xsl:template match="//core:result/core:content/activity:place">
    <xsl:call-template name="table-item">
      <xsl:with-param name="value">
        <xsl:value-of select="."/>
      </xsl:with-param>
      <xsl:with-param name="title">
        <xsl:value-of select="ll:getLL('place')"/>
      </xsl:with-param>
    </xsl:call-template>
  </xsl:template>
  
  <xsl:template match="//core:result/core:content/activity:subTitle">
    <xsl:call-template name="table-item">
      <xsl:with-param name="value">
        <xsl:apply-templates select="." mode="localize" />
      </xsl:with-param>
      <xsl:with-param name="title">
        <xsl:value-of select="ll:getLL('subTitle')"/>
      </xsl:with-param>
    </xsl:call-template>
  </xsl:template>


  <!--
   //////////////////////////////////////////////////////
   /////////////Lecture Fields End //////////////////////
   //////////////////////////////////////////////////////  
   -->

  <!--    
   //////////////////////////////////////////////////////
   /////////////Appearance Fields Start /////////////////
   //////////////////////////////////////////////////////   
   -->

  <xsl:template match="//core:result/core:content/activity:mediumName">
    <xsl:call-template name="table-item">
      <xsl:with-param name="value">
        <xsl:value-of select="."/>
      </xsl:with-param>
      <xsl:with-param name="title">
        <xsl:value-of select="ll:getLL('mediumName')"/>
      </xsl:with-param>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="//core:result/core:content/activity:producerName">
    <xsl:call-template name="table-item">
      <xsl:with-param name="value">
        <xsl:value-of select="."/>
      </xsl:with-param>
      <xsl:with-param name="title">
        <xsl:value-of select="ll:getLL('producerName')"/>
      </xsl:with-param>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="//core:result/core:content/activity:subject">
    <xsl:call-template name="table-item">
      <xsl:with-param name="value">
        <xsl:value-of select="."/>
      </xsl:with-param>
      <xsl:with-param name="title">
        <xsl:value-of select="ll:getLL('subject')"/>
      </xsl:with-param>
    </xsl:call-template>
  </xsl:template>

  <!--
   //////////////////////////////////////////////////////
   /////////////Appearance Fields End ///////////////////
   //////////////////////////////////////////////////////  
   -->


  <!--    
   //////////////////////////////////////////////////////
   /////////////ConferenceParticipation Fields Start ////
   //////////////////////////////////////////////////////   
   -->

  <xsl:template match="//core:result/core:content/activity:city">
    <xsl:call-template name="table-item">
      <xsl:with-param name="value">
        <xsl:value-of select="."/>
      </xsl:with-param>
      <xsl:with-param name="title">
        <xsl:value-of select="ll:getLL('city')"/>
      </xsl:with-param>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="//core:result/core:content/activity:conferenceNumber">
    <xsl:call-template name="table-item">
      <xsl:with-param name="value">
        <xsl:value-of select="."/>
      </xsl:with-param>
      <xsl:with-param name="title">
        <xsl:value-of select="ll:getLL('conferenceNumber')"/>
      </xsl:with-param>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="//core:result/core:content/activity:country">
    <xsl:call-template name="table-item">
      <xsl:with-param name="value">
        <xsl:apply-templates select="core:term" mode="localize" />
      </xsl:with-param>
      <xsl:with-param name="title">
        <xsl:value-of select="ll:getLL('country')"/>
      </xsl:with-param>
    </xsl:call-template>
  </xsl:template>

  <!--
   //////////////////////////////////////////////////////
   /////////////ConferenceParticipation Fields End //////
   //////////////////////////////////////////////////////  
   -->

  <!--    
   //////////////////////////////////////////////////////
   /////////////Ongoing Fields Start ////////////////////
   //////////////////////////////////////////////////////   
   -->

  <xsl:template match="//core:result/core:content/activity:institutionName">
    <xsl:call-template name="table-item">
      <xsl:with-param name="value">
        <xsl:apply-templates select="." mode="localize" />
      </xsl:with-param>
      <xsl:with-param name="title">
        <xsl:value-of select="ll:getLL('institutionName')"/>
      </xsl:with-param>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="//core:result/core:content/activity:issnIsbnSerials">
    <xsl:call-template name="table-item">
      <!--TODO: ET ELLER ANDET KORREKT-->
      <xsl:with-param name="value">
        <xsl:value-of select="."/>
      </xsl:with-param>
      <xsl:with-param name="title">
        <xsl:value-of select="ll:getLL('issnIsbnSerials')"/>
      </xsl:with-param>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="//core:result/core:content/activity:publicationPlace">
    <xsl:call-template name="table-item">
      <xsl:with-param name="value">
        <xsl:apply-templates select="." mode="localize" />
      </xsl:with-param>
      <xsl:with-param name="title">
        <xsl:value-of select="ll:getLL('publicationPlace')"/>
      </xsl:with-param>
    </xsl:call-template>
  </xsl:template>

  <!--
   //////////////////////////////////////////////////////
   /////////////Ongoing Fields End //////////////////////
   //////////////////////////////////////////////////////  
   -->

  <!--    
   //////////////////////////////////////////////////////
   /////////////Other Fields Start //////////////////////
   //////////////////////////////////////////////////////   
   -->

  <xsl:template match="//core:result/core:content/activity:specificCountry">
    <xsl:call-template name="table-item">
      <xsl:with-param name="value">
        <xsl:apply-templates select="core:term" mode="localize" />
      </xsl:with-param>
      <xsl:with-param name="title">
        <xsl:value-of select="ll:getLL('specificCountry')"/>
      </xsl:with-param>
    </xsl:call-template>
  </xsl:template>

  <!--
   //////////////////////////////////////////////////////
   /////////////Other Fields End ///////////////////////
   //////////////////////////////////////////////////////  
   -->

  <!--
   //////////////////////////////////////////////////////
   /////////////Common Fields Start /////////////////////
   //////////////////////////////////////////////////////
   -->

   <xsl:template match="//core:result/core:content/activity:title">
    <xsl:call-template name="table-item">
      <xsl:with-param name="value">
        <xsl:apply-templates select="." mode="localize" />
      </xsl:with-param>
      <xsl:with-param name="title">
        <xsl:value-of select="ll:getLL('title')"/>
      </xsl:with-param>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="//core:result/core:content/activity:abstract">
    <xsl:call-template name="table-item">
      <xsl:with-param name="value">
        <xsl:apply-templates select="." mode="localize" />
      </xsl:with-param>
      <xsl:with-param name="title">
        <xsl:value-of select="ll:getLL('abstract')"/>
      </xsl:with-param>
    </xsl:call-template>
  </xsl:template>

   
   <!--
   //////////////////////////////////////////////////////
   /////////////Common Fields End ///////////////////////
   //////////////////////////////////////////////////////
   -->






  <xsl:template name="table-item">
    <xsl:param name="value" />
    <xsl:param name="title" />
    <tr valign="top">
      <td style="line-height: 20px; padding-right: 10px; color:#666666;" align="right" nowrap="nowrap">
        <xsl:copy-of select="$title"/>
        <xsl:text> :</xsl:text>
      </td>
      <td style="line-height: 20px;">
        <xsl:copy-of select="$value"/>
      </td>
    </tr>
  </xsl:template>

  <xsl:template match="//result/item/start|//result/item/end">
    <xsl:call-template name="table-item">
      <xsl:with-param name="value">
        <xsl:value-of select="date:day-in-month(.)"/>
        <xsl:text>.</xsl:text>
        <xsl:value-of select="date:month-in-year(.)"/>
        <xsl:text>.</xsl:text>
        <xsl:value-of select="date:year(.)"/>
      </xsl:with-param>
      <xsl:with-param name="title">
        <xsl:value-of select="ll:getLL(concat(local-name(), 'Date'))"/>
      </xsl:with-param>
    </xsl:call-template>
  </xsl:template>
  
  


  <!-- All other XML-types -->
  <xsl:template match="//result/item/name_pri|//result/item/name_sec|//result/item/subtitle_pri|//result/item/subtitle_sec|
                        //result/item/subject|//result/item/conferenceTitle|
                        //result/item/bodyTitle_pri|//result/item/bodyTitle_sec">
    <xsl:call-template name="table-item">
      <xsl:with-param name="value" >
        <xsl:apply-templates />
      </xsl:with-param>
      <xsl:with-param name="title">
        <xsl:value-of select="ll:getLL(local-name())"/>
      </xsl:with-param>
    </xsl:call-template>
  </xsl:template>

  <!--Non-XML types (String, Integer) -->
  <xsl:template match="//result/item/*">
    <xsl:call-template name="table-item">
      <xsl:with-param name="value">
        <xsl:value-of select="." disable-output-escaping="yes"/>
      </xsl:with-param>
      <xsl:with-param name="title">
        <xsl:value-of select="ll:getLL(local-name())"/>
      </xsl:with-param>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="@*|node()">
    <xsl:copy>
      <xsl:apply-templates select="@*|node()"/>
    </xsl:copy>
  </xsl:template>

</xsl:stylesheet>