<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns="http://www.w3.org/1999/xhtml"
                xmlns:fn="http://www.w3.org/2005/02/xpath-functions"
                xmlns:regexp="http://exslt.org/regular-expressions"
                xmlns:ll="http://typo3.org/extensions/repository/view/pure/current/"
                xmlns:php="http://php.net/xsl"
                xmlns:func="http://exslt.org/functions"
                
                xmlns:core="http://atira.dk/schemas/pure4/model/core/stable"
                xmlns:publication="http://atira.dk/schemas/pure4/model/abstractpublication/stable"
                xmlns:person="http://atira.dk/schemas/pure4/model/abstractperson/stable"
                xmlns:organisation="http://atira.dk/schemas/pure4/model/abstractorganisation/stable"
                xmlns:extensions="http://atira.dk/schemas/pure4/model/extensions/stable"
                xmlns:event="http://atira.dk/schemas/pure4/model/abstractevent/stable"
                xmlns:stab="http://atira.dk/schemas/pure4/dk/model/publication/stable"
                
                xmlns:str="http://exslt.org/strings"
                exclude-result-prefixes="fn str regexp php ll func core publication person extensions organisation event stab">
  <xsl:import href="localization.xsl" />
  <xsl:param name="ll:localizationFile" select="'locallang_person.xml'" />

  <xsl:key name="firstKeywordKey" match="//compilations/item/paths/item" use="keywords/item[1]/id" />

  <xsl:param name="pureUrl" />
  <xsl:param name="foldOutFirstTab" />

  <xsl:output omit-xml-declaration="yes" encoding="utf-8" />

  <xsl:template match="/">
    <div class="pure-basic-person" >
      <xsl:for-each select="//core:result/core:content">
        <div class="vcard pure-basic-person-single pure-basic-organisation-single">

          <!--Generel person info-->
          <h2 class="fn">
            <xsl:apply-templates select="organisation:name" mode="localize" />
          </h2>
          
          <div>
            <xsl:apply-templates select="organisation:phone" />
            <xsl:apply-templates select="organisation:fax" />
          </div>

          <h4>
            <xsl:value-of select="ll:getLL('mail_address')"/>
          </h4>

          <div class="adr">
            <!--<abbr class="type" title="work"></abbr>-->
            <span class="street-address">
              <xsl:for-each select="str:tokenize(organisation:address/extensions:road,';')">
                <xsl:value-of select="."/>
                <br />
              </xsl:for-each>
            </span>

            <span class="postal-code">
              <xsl:value-of select="organisation:address/extensions:postalcode"/>
            </span>
            <xsl:text>&#160;</xsl:text>
            <span class="locality">
              <xsl:value-of select="organisation:address/extensions:city"/>
            </span>
            <br />
          </div>

          <br />
          <xsl:if test="organisation:website">
            <xsl:element name="a" >
              <xsl:attribute name="href">
                <xsl:apply-templates select="organisation:website" mode="localize" />
              </xsl:attribute>
              <xsl:value-of select="ll:getLL('supplementary_homepage')"/>
            </xsl:element>
          </xsl:if>

          <xsl:variable name="gotPublications" select="php:function('tx_pure_xsltfunctions::infoExistForOrganisation', $pureUrl, 'publications', string(@uuid))" />
          <xsl:variable name="gotActivities" select="php:function('tx_pure_xsltfunctions::infoExistForOrganisation', $pureUrl, 'activities', string(@uuid))" />


          <!--TODO: Check for Danish/English (da_DK/en_GB)-->
          <xsl:if test="person:KeywordContainersTODO
              or person:profileInformation/extensions:customField[contains(extensions:typeClassification/core:uri, '/dk/atira/pure/person/customfields/CurriculumVitae') and extensions:value/core:localizedString]
              or $gotPublications
              or $gotActivities
              or person:profileInformation/extensions:customField[contains(extensions:typeClassification/core:uri, '/dk/atira/pure/person/customfields/ResearchAreas') and extensions:value/core:localizedString]
              or person:profileInformation/extensions:customField[contains(extensions:typeClassification/core:uri, '/dk/atira/pure/person/customfields/ResearchAndEducationInformation') and extensions:value/core:localizedString]
              ">
            <xsl:element name="div">
              <xsl:attribute name="class">
                <xsl:text>pure-tabs</xsl:text>
                <xsl:if test="$foldOutFirstTab = 'true'">
                  <xsl:text> pure-tabs-foldOutFirst</xsl:text>
                </xsl:if>
              </xsl:attribute>


              <ul class="pure-tabs-ul">
                <xsl:if test="person:KeywordContainersTODO">
                  <li>
                    <xsl:element name="a">
                      <xsl:attribute name="class">
                        <xsl:text>pure-tab pure-tab-element</xsl:text>
                        <xsl:if test="$tabIndexToOpen='KEYWORDCLASS'">
                          <xsl:text> pure-tab-open</xsl:text>
                        </xsl:if>
                      </xsl:attribute>
                      <xsl:attribute name="href">
                        <xsl:value-of select="concat('#keyword',generate-id(.))"/>
                      </xsl:attribute>
                      <span>
                        <xsl:value-of select="ll:getLL('research')"/>
                      </span>
                    </xsl:element>
                  </li>
                  <!--<xsl:apply-templates select="typo3/links/keywordUrl" />-->
                </xsl:if>

                <xsl:if test="person:profileInformation/extensions:customField[contains(extensions:typeClassification/core:uri, '/dk/atira/pure/person/customfields/CurriculumVitae') and extensions:value/core:localizedString]">
                  <!--<xsl:apply-templates select="typo3/links/cvUrl" /> -->
                  <li>
                    <xsl:element name="a">
                      <xsl:attribute name="class">
                        <xsl:text>pure-tab pure-tab-element</xsl:text>
                        <xsl:if test="$tabIndexToOpen='CVCLASS'">
                          <xsl:text> pure-tab-open</xsl:text>
                        </xsl:if>
                      </xsl:attribute>
                      <xsl:attribute name="href">
                        <xsl:value-of select="concat('#cv',generate-id(.))"/>
                      </xsl:attribute>
                      <span>
                        <xsl:value-of select="ll:getLL('cv')"/>
                      </span>
                    </xsl:element>
                  </li>
                </xsl:if>

                <xsl:if test="$gotPublications">
                  <xsl:apply-templates select="typo3/links/publicationUrl" />
                </xsl:if>
                <xsl:if test="$gotActivities">
                  <xsl:apply-templates select="typo3/links/activitiesUrl" />
                </xsl:if>

                <xsl:if test="person:profileInformation/extensions:customField[contains(extensions:typeClassification/core:uri, '/dk/atira/pure/person/customfields/ResearchAreas') and extensions:value/core:localizedString]">
                  <li>
                    <xsl:element name="a">
                      <xsl:attribute name="class">
                        <xsl:text>pure-tab pure-tab-element</xsl:text>
                        <xsl:if test="$tabIndexToOpen='MISCCLASS'">
                          <xsl:text> pure-tab-open</xsl:text>
                        </xsl:if>
                      </xsl:attribute>
                      <xsl:attribute name="href">
                        <xsl:value-of select="concat('#misc',generate-id(.))"/>
                      </xsl:attribute>
                      <span>
                        <xsl:value-of select="ll:getLL('further-information')"/>
                      </span>
                    </xsl:element>
                  </li>
                </xsl:if>
                <xsl:if test="person:profileInformation/extensions:customField[contains(extensions:typeClassification/core:uri, '/dk/atira/pure/person/customfields/ResearchAndEducationInformation') and extensions:value/core:localizedString]">
                  <li>
                    <xsl:element name="a">
                      <xsl:attribute name="class">
                        <xsl:text>pure-tab pure-tab-element</xsl:text>
                        <xsl:if test="$tabIndexToOpen='EXTRACLASS'">
                          <xsl:text> pure-tab-open</xsl:text>
                        </xsl:if>
                      </xsl:attribute>
                      <xsl:attribute name="href">
                        <xsl:value-of select="concat('#extra',generate-id(.))"/>
                      </xsl:attribute>
                      <span>
                        <xsl:value-of select="ll:getLL('extra_info')"/>
                      </span>
                    </xsl:element>
                  </li>
                </xsl:if>
              </ul>

              <xsl:if test="person:KeywordContainersTODO">
                <div id="keyword{generate-id(.)}">
                  <div class="person-keyword">
                    <xsl:for-each select="//compilations/item/paths/item[count(. | key('firstKeywordKey', keywords/item[1]/id)[1]) = 1]">
                      <h3>
                        <a href="{keywords/item[1]/keywordUrl}">
                          <xsl:value-of select="ll:localize(keywords/item[1]/title_pri, keywords/item[1]/title_sec)"/>
                        </a>
                      </h3>
                      <p>
                        <xsl:for-each select="key('firstKeywordKey', keywords/item[1]/id)">

                          <xsl:for-each select="keywords/item[position()>1]">
                            <a href="{keywordUrl}">
                              <xsl:value-of select="ll:localize(title_pri, title_sec)"/>
                            </a>
                            <xsl:if test="position()!=last()">
                              <span class="au-pil"> &#9658; </span>
                            </xsl:if>
                          </xsl:for-each>
                          <xsl:for-each select="userKeywords/item">
                            <span class="au-pil"> &#8226; </span>
                            <xsl:value-of select="ll:localize(title_pri, title_sec)"/>
                          </xsl:for-each>
                          <br />

                        </xsl:for-each>
                      </p>
                    </xsl:for-each>
                  </div>
                </div>
              </xsl:if>

              <xsl:if test="person:profileInformation/extensions:customField[contains(extensions:typeClassification/core:uri, '/dk/atira/pure/person/customfields/CurriculumVitae') and extensions:value/core:localizedString]">
                <div id="cv{generate-id(.)}">
                  <div class="cv-info">
                    <xsl:apply-templates select="person:profileInformation/extensions:customField[contains(extensions:typeClassification/core:uri, '/dk/atira/pure/person/customfields/CurriculumVitae') and extensions:value/core:localizedString]/extensions:value" mode="localize" />
                  </div>
                </div>
              </xsl:if>

              <xsl:if test="person:profileInformation/extensions:customField[contains(extensions:typeClassification/core:uri, '/dk/atira/pure/person/customfields/ResearchAreas') and extensions:value/core:localizedString]">
                <div id="misc{generate-id(.)}">
                  <div class="further-info">
                    <xsl:apply-templates select="person:profileInformation/extensions:customField[contains(extensions:typeClassification/core:uri, '/dk/atira/pure/person/customfields/ResearchAreas') and extensions:value/core:localizedString]/extensions:value" mode="localize" />
                  </div>
                </div>
              </xsl:if>
              <xsl:if test="person:profileInformation/extensions:customField[contains(extensions:typeClassification/core:uri, '/dk/atira/pure/person/customfields/ResearchAndEducationInformation') and extensions:value/core:localizedString]">
                <div id="extra{generate-id(.)}">
                  <div class="extra-info">
                    <xsl:apply-templates select="person:profileInformation/extensions:customField[contains(extensions:typeClassification/core:uri, '/dk/atira/pure/person/customfields/ResearchAndEducationInformation') and extensions:value/core:localizedString]/extensions:value" mode="localize" />
                  </div>
                </div>
              </xsl:if>
            </xsl:element>
          </xsl:if>
          <br />
        </div>
      </xsl:for-each>
    </div>
  </xsl:template>



  <xsl:template match="typo3/links/cvUrl">
    <li>
      <xsl:element name="a">
        <xsl:attribute name="class">
          <xsl:text>pure-tab</xsl:text>
          <xsl:if test="$tabIndexToOpen='CVCLASS'">
            <xsl:text> pure-tab-open</xsl:text>
          </xsl:if>
        </xsl:attribute>
        <xsl:attribute name="href">
          <xsl:value-of select="."/>
        </xsl:attribute>
        <span>
          <xsl:value-of select="ll:getLL('cv')"/>
        </span>
      </xsl:element>
    </li>
  </xsl:template>

  <xsl:template match="typo3/links/publicationUrl">
    <li>
      <xsl:element name="a">
        <xsl:attribute name="class">
          <xsl:text>pure-tab</xsl:text>
          <xsl:if test="$tabIndexToOpen='PUBCLASS'">
            <xsl:text> pure-tab-open</xsl:text>
          </xsl:if>
        </xsl:attribute>
        <xsl:attribute name="href">
          <xsl:value-of select="."/>
        </xsl:attribute>
        <span>
          <xsl:value-of select="ll:getLL('publications')"/>
        </span>
      </xsl:element>
    </li>
  </xsl:template>

  <xsl:template match="typo3/links/activitiesUrl">
    <li>
      <xsl:element name="a">
        <xsl:attribute name="class">
          <xsl:text>pure-tab</xsl:text>
          <xsl:if test="$tabIndexToOpen='ACTCLASS'">
            <xsl:text> pure-tab-open</xsl:text>
          </xsl:if>
        </xsl:attribute>
        <xsl:attribute name="href">
          <xsl:value-of select="."/>
        </xsl:attribute>
        <span>
          <xsl:value-of select="ll:getLL('activities')"/>
        </span>
      </xsl:element>
    </li>
  </xsl:template>

  <xsl:template match="organisation:phone">
    <strong>
      <xsl:value-of select="ll:getLL('tel')"/>
      <xsl:text>: </xsl:text>
    </strong>
    <span class="tel">
      <xsl:choose>
        <xsl:when test="string-length(.)=8">
          <xsl:value-of select="ll:getLL('phoneprefix.DK')"/>
          <xsl:value-of select="substring(.,1,4)"/>
          <xsl:text>&#160;</xsl:text>
          <xsl:value-of select="substring(.,5,4)"/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of select="."/>
        </xsl:otherwise>
      </xsl:choose>
    </span>
    <br />
  </xsl:template>


  <xsl:template match="organisation:fax">
    <span class="tel">
      <span class="type">
        <strong>
          <xsl:value-of select="ll:getLL('fax')"/>
          <xsl:text>: </xsl:text>
        </strong>
      </span>
      <span class="value">
        <xsl:choose>
          <xsl:when test="string-length(.)=8">
            <xsl:value-of select="ll:getLL('phoneprefix.DK')"/>
            <xsl:value-of select="substring(.,1,4)"/>
            <xsl:text>&#160;</xsl:text>
            <xsl:value-of select="substring(.,5,4)"/>
          </xsl:when>
          <xsl:otherwise>
            <xsl:value-of select="."/>
          </xsl:otherwise>
        </xsl:choose>
      </span>
    </span>
    <br />
  </xsl:template>

  
</xsl:stylesheet>