<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns="http://www.w3.org/1999/xhtml"
                xmlns:fn="http://www.w3.org/2005/02/xpath-functions"
                xmlns:regexp="http://exslt.org/regular-expressions"
                xmlns:ll="http://typo3.org/extensions/repository/view/pure/current/"
                xmlns:php="http://php.net/xsl"
                
                xmlns:core="http://atira.dk/schemas/pure4/model/core/stable"
                xmlns:publication="http://atira.dk/schemas/pure4/model/abstractpublication/stable"
                xmlns:person="http://atira.dk/schemas/pure4/model/abstractperson/stable"
                xmlns:extensions="http://atira.dk/schemas/pure4/model/extensions/stable"
                xmlns:organisation="http://atira.dk/schemas/pure4/model/abstractorganisation/stable"
                xmlns:event="http://atira.dk/schemas/pure4/model/abstractevent/stable"
                xmlns:stab="http://atira.dk/schemas/pure4/dk/model/publication/stable"
                
                xmlns:str="http://exslt.org/strings"
                exclude-result-prefixes="fn str regexp php ll core publication person extensions organisation event stab">
  <xsl:import href="localization.xsl" />
  <xsl:param name="ll:localizationFile" select="'locallang_person.xml'" />
  <xsl:param name="hideJobtitleInList" />
  
  <xsl:output encoding="utf-8" />

  <xsl:template match="/">
    <div class="pure-small-person" >
      <xsl:for-each select="//core:result/core:content">
        <div class="vcard pure-small-person-single">
          <p>
            <xsl:element name="a">
              <xsl:attribute name="class">
                <xsl:text>fn</xsl:text>
              </xsl:attribute>
              <xsl:attribute name="href">
                <xsl:value-of select="typo3/links/personUrl"/>
              </xsl:attribute>
              <xsl:attribute name="title">
                <xsl:value-of select="person:name/core:firstName"/>
                <xsl:text> </xsl:text>
                <xsl:value-of select="person:name/core:lastName"/>
              </xsl:attribute>
              <strong>
                <span class="given-name">
                  <xsl:value-of select="person:name/core:firstName"/>
                </span>
                <xsl:text>&#160;</xsl:text>
                <span class="family-name">
                  <xsl:value-of select="person:name/core:lastName"/>
                </span>
              </strong>
            </xsl:element>
            
            <xsl:variable name="primaryOrganisation" select="person:organisationAssociations/person:organisationAssociation[not(person:period/extensions:endDate)][1]" />
            <xsl:if test="not($hideJobtitleInList)">
                <xsl:if test="$primaryOrganisation/person:jobTitle">
                    <span class="title">
                        <br />
                      <xsl:apply-templates select="$primaryOrganisation/person:jobTitle/core:term" />
                    </span>
                </xsl:if>
            </xsl:if>
            <br />
            <xsl:apply-templates select="$primaryOrganisation/person:phone" />
            <xsl:apply-templates select="$primaryOrganisation/person:fax" />
            <xsl:apply-templates select="$primaryOrganisation/emailLink" />
          </p>

        </div>
        <xsl:if test="position()!=last()">
          <hr />
        </xsl:if>
      </xsl:for-each>
    </div>
  </xsl:template>

  <xsl:template match="//core:result/core:content/person:organisationAssociations/person:organisationAssociation/person:phone">
    <strong>
      <xsl:value-of select="ll:getLL('tel')"/>
      <xsl:text>: </xsl:text>
    </strong>
    <span class="tel">
      <xsl:choose>
        <xsl:when test="string-length(.)=8">
          <xsl:value-of select="ll:getLL('phoneprefix.DK')"/>
          <xsl:value-of select="substring(.,1,4)"/>
          <xsl:text> </xsl:text>
          <xsl:value-of select="substring(.,5,4)"/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of select="."/>
        </xsl:otherwise>
      </xsl:choose>
    </span>
    <br />
  </xsl:template>


  <xsl:template match="//core:result/core:content/person:organisationAssociations/person:organisationAssociation/person:fax">
    <span class="tel">
      <span class="type">
        <strong>
          <xsl:value-of select="ll:getLL('fax')"/>
          <xsl:text>: </xsl:text>
        </strong>
      </span>
      <span class="value">
        <xsl:choose>
          <xsl:when test="string-length(.)=8">
            <xsl:value-of select="ll:getLL('phoneprefix.DK')"/>
            <xsl:value-of select="substring(.,1,4)"/>
            <xsl:text> </xsl:text>
            <xsl:value-of select="substring(.,5,4)"/>
          </xsl:when>
          <xsl:otherwise>
            <xsl:value-of select="."/>
          </xsl:otherwise>
        </xsl:choose>
      </span>
    </span>
    <br />
  </xsl:template>

  <xsl:template match="//core:result/core:content/person:organisationAssociations/person:organisationAssociation/emailLink">
    <strong>
      <xsl:value-of select="ll:getLL('email')"/>
      <xsl:text>: </xsl:text>
    </strong>
    <span class="email">
      <xsl:value-of select="." disable-output-escaping="yes"/>
    </span>
    <br />
  </xsl:template>


</xsl:stylesheet>